@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 
@@ -30,26 +30,16 @@
     $result = db_query($query);
 
 	# updated the last_updated date
-	bug_date_update( $f_id );
+	$result = bug_date_update( $f_id );
 
 	# send assigned to email
 	email_assign( $f_id );
 
 	# Determine which view page to redirect back to.
-	$t_redirect_url = get_view_redirect_url( $f_id );
-
-	if (( ON == $g_quick_proceed )&&( $result )) {
-		print_header_redirect( $t_redirect_url );
-	}
-?>
-<?php print_page_top1() ?>
-<?php
+	$t_redirect_url = get_view_redirect_url( $f_id, 1 );
 	if ( $result ) {
-		print_meta_redirect( $t_redirect_url );
+		print_header_redirect( $t_redirect_url );
+	} else {
+		print_mantis_error( ERROR_GENERIC );
 	}
-?>
-<?php print_page_top2() ?>
-
-<?php print_proceed( $result, $query, $t_redirect_url ) ?>
-
-<?php print_page_bot1( __FILE__ ) ?>
\ No newline at end of file
+?>
\ No newline at end of file
