@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the files README and LICENSE for details
 ?>
@@ -10,7 +10,8 @@
 ?>
 <?php # Upload File Form BEGIN ?>
 <?php if ( ( ON == $g_allow_file_upload )&&
-		( $v_status < RESOLVED ) ) { ?>
+		( $v_status < RESOLVED )&&
+		( access_level_check_greater_or_equal( REPORTER ) ) ) { ?>
 <p>
 <div align="center">
 <form method="post" enctype="multipart/form-data" action="<?php echo $g_bug_file_add ?>">
@@ -26,7 +27,7 @@
 	</td>
 	<td width="85%">
 		<input type="hidden" name="f_id" value="<?php echo $f_id ?>">
-		<input type="hidden" name="max_file_size" value="5000000">
+		<input type="hidden" name="max_file_size" value="<?php echo $g_max_file_size ?>">
 		<input name="f_file" type="file" size="60">
 		<input type="submit" value="<?php echo $s_upload_file_button ?>">
 	</td>
