@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -28,17 +28,34 @@
     $t_bug_text_id = db_result( $result, 0, 0 );
 
 	# prevent warnings
-	if (!isset( $f_os )) {
-		$f_os = "";
+	if ( !isset( $f_os ) ) {
+		$f_os = get_bug_field( $f_id, "os" );
 	}
-	if (!isset( $f_os_build )) {
-		$f_os_build = "";
+	if ( !isset( $f_os_build ) ) {
+		$f_os_build = get_bug_field( $f_id, "os_build" );
 	}
-	if (!isset( $f_platform )) {
-		$f_platform = "";
+	if ( !isset( $f_platform ) ) {
+		$f_platform = get_bug_field( $f_id, "platform" );
 	}
-	if (!isset( $f_version )) {
-		$f_version = "";
+	if ( !isset( $f_version ) ) {
+		$f_version = get_bug_field( $f_id, "version" );
+	}
+	if ( !isset( $f_build ) ) {
+		$f_build = get_bug_field( $f_id, "build" );
+	}
+	if ( !isset( $f_eta ) ) {
+		$f_eta = get_bug_field( $f_id, "eta" );
+	}
+	if ( !isset( $f_projection ) ) {
+		$f_projection = get_bug_field( $f_id, "projection" );
+	}
+	if ( !isset( $f_resolution ) ) {
+		$f_resolution = get_bug_field( $f_id, "resolution" );
+	}
+	if ( !isset( $f_steps_to_reproduce ) ) {
+		$f_steps_to_reproduce = get_bug_text_field( $f_id, "steps_to_reproduce" );
+	} else {
+		$f_steps_to_reproduce = string_prepare_textarea( $f_steps_to_reproduce );
 	}
 
 	# prepare strings
@@ -46,9 +63,9 @@
 	$f_os_build 				= string_prepare_text( $f_os_build );
 	$f_platform					= string_prepare_text( $f_platform );
 	$f_version 					= string_prepare_text( $f_version );
+	$f_build 					= string_prepare_text( $f_build );
 	$f_summary					= string_prepare_text( $f_summary );
 	$f_description 				= string_prepare_textarea( $f_description );
-	$f_steps_to_reproduce 		= string_prepare_textarea( $f_steps_to_reproduce );
 	$f_additional_information 	= string_prepare_textarea( $f_additional_information );
 
     if ( ( $f_handler_id != 0 ) AND ( NEW_ == $f_status ) ) {
@@ -62,7 +79,10 @@
 				priority='$f_priority', status='$f_status',
 				projection='$f_projection', duplicate_id='$f_duplicate_id',
 				resolution='$f_resolution', handler_id='$f_handler_id',
-				eta='$f_eta', summary='$f_summary'
+				eta='$f_eta', summary='$f_summary',
+				os='$f_os', os_build='$f_os_build',
+				platform='$f_platform', build='$f_build',
+				version='$f_version', view_state='$f_view_state'
     		WHERE id='$f_id'";
    	$result = db_query($query);
 
@@ -74,7 +94,7 @@
    	$result = db_query($query);
 
 	# updated the last_updated date
-	bug_date_update( $f_id );
+	$result = bug_date_update( $f_id );
 
 	# If we should notify and it's in feedback state then send an email
 	switch ( $f_status ) {
@@ -94,18 +114,9 @@
 
 	# Determine which view page to redirect back to.
 	$t_redirect_url = get_view_redirect_url( $f_id, 1 );
-	if (( ON == $g_quick_proceed )&&( $result )) {
-		print_header_redirect( $t_redirect_url );
-	}
-?>
-<?php print_page_top1() ?>
-<?php
 	if ( $result ) {
-		print_meta_redirect( $t_redirect_url );
+		print_header_redirect( $t_redirect_url );
+	} else {
+		print_mantis_error( ERROR_GENERIC );
 	}
 ?>
-<?php print_page_top2() ?>
-
-<?php print_proceed( $result, $query, $t_redirect_url ) ?>
-
-<?php print_page_bot1( __FILE__ ) ?>
