@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -27,6 +27,9 @@
     $result = db_query( $query );
 	$row = db_fetch_array( $result );
 	extract( $row, EXTR_PREFIX_ALL, "v" );
+	
+	# if bug is private, make sure user can view private bugs
+	access_bug_check( $f_id, $v_view_state );
 
     $query = "SELECT *
     		FROM $g_mantis_bug_text_table
@@ -36,13 +39,8 @@
 	extract( $row, EXTR_PREFIX_ALL, "v2" );
 
 	# prepare strings for display
-	$v_os 						= string_display( $v_os );
-	$v_os_build 				= string_display( $v_os_build );
-	$v_platform					= string_display( $v_platform );
-	$v_version 					= string_display( $v_version );
 	$v_summary					= string_edit_text( $v_summary );
 	$v2_description 			= string_edit_textarea( $v2_description );
-	$v2_steps_to_reproduce 		= string_edit_textarea( $v2_steps_to_reproduce );
 	$v2_additional_information 	= string_edit_textarea( $v2_additional_information );
 ?>
 <?php print_page_top1() ?>
@@ -54,14 +52,6 @@
 <input type="hidden" name="f_id"                 value="<?php echo $v_id ?>">
 <input type="hidden" name="f_old_status"         value="<?php echo $v_status ?>">
 <input type="hidden" name="f_old_handler_id"     value="<?php echo $v_handler_id ?>">
-<input type="hidden" name="f_resolution"         value="<?php echo $v_resolution ?>">
-<input type="hidden" name="f_projection"         value="<?php echo $v_projection ?>">
-<input type="hidden" name="f_eta"                value="<?php echo $v_eta ?>">
-<input type="hidden" name="f_os"                 value="<?php echo $v_os ?>">
-<input type="hidden" name="f_os_build"           value="<?php echo $v_os_build ?>">
-<input type="hidden" name="f_platform"           value="<?php echo $v_platform ?>">
-<input type="hidden" name="f_version"            value="<?php echo $v_version ?>">
-<input type="hidden" name="f_steps_to_reproduce" value="<?php echo $v2_steps_to_reproduce ?>">
 <tr>
 	<td class="form-title" colspan="3">
 		<?php echo $s_updating_bug_simple_title ?>
@@ -114,12 +104,12 @@
 	</td>
 	<td>
 		<select name="f_severity">
-			<?php print_enum_string_option_list( $s_severity_enum_string, $v_severity ) ?>
+			<?php print_enum_string_option_list( "severity", $v_severity ) ?>
 		</select>
 	</td>
 	<td>
 		<select name="f_reproducibility">
-			<?php print_enum_string_option_list( $s_reproducibility_enum_string, $v_reproducibility ) ?>
+			<?php print_enum_string_option_list( "reproducibility", $v_reproducibility ) ?>
 		</select>
 	</td>
 	<td>
@@ -130,17 +120,28 @@
 	</td>
 </tr>
 <tr>
-	<td class="spacer" colspan="6">
-		&nbsp;
+	<td class="spacer" colspan="6">&nbsp;
+		
 	</td>
 </tr>
 <tr class="row-1">
 	<td class="category">
 		<?php echo $s_reporter ?>
 	</td>
-	<td colspan="5">
+	<td>
 		<?php print_user( $v_reporter_id ) ?>
 	</td>
+	<td class="category">
+		<?php echo $s_view_status ?>
+	</td>
+	<td>
+		<select name="f_view_state">
+			<?php print_enum_string_option_list( "project_view_state", $v_view_state) ?>
+		</select>
+	</td>
+	<td colspan="2">&nbsp;
+		
+	</td>
 </tr>
 <tr class="row-2">
 	<td class="category">
@@ -159,26 +160,26 @@
 	</td>
 	<td>
 		<select name="f_priority">
-			<?php print_enum_string_option_list( $s_priority_enum_string, $v_priority ) ?>
+			<?php print_enum_string_option_list( "priority", $v_priority ) ?>
 		</select>
 	</td>
 	<td class="category">
 		<?php echo $s_resolution ?>
 	</td>
 	<td>
-		<?php echo get_enum_element( $s_resolution_enum_string, $v_resolution ) ?>
+		<?php echo get_enum_element( "resolution", $v_resolution ) ?>
 	</td>
-	<td colspan="2">
-		&nbsp;
+	<td colspan="2">&nbsp;
+		
 	</td>
 </tr>
 <tr class="row-2">
 	<td class="category">
 		<?php echo $s_status ?>
 	</td>
-	<td>
+	<td <?php echo get_status_bgcolor( $v_status ) ?>>
 		<select name="f_status">
-			<?php print_enum_string_option_list( $s_status_enum_string, $v_status ) ?>
+			<?php print_enum_string_option_list( "status", $v_status ) ?>
 		</select>
 	</td>
 	<td class="category">
@@ -187,13 +188,13 @@
 	<td>
 		<?php echo $v_duplicate_id ?>
 	</td>
-	<td colspan="2">
-		&nbsp;
+	<td colspan="2">&nbsp;
+		
 	</td>
 </tr>
 <tr>
-	<td class="spacer" colspan="6">
-		&nbsp;
+	<td class="spacer" colspan="6">&nbsp;
+		
 	</td>
 </tr>
 <tr class="row-1">
@@ -228,4 +229,4 @@
 </form>
 </table>
 
-<?php print_page_bot1( __FILE__ ) ?>
\ No newline at end of file
+<?php print_page_bot1( __FILE__ ) ?>
