@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -18,16 +18,10 @@
     		WHERE id='$f_id'";
    	$result = db_query($query);
 
-   	$t_redirect_url = $g_view_bug_advanced_page."?f_id=".$f_id;
-?>
-<?php print_page_top1() ?>
-<?php
+	$t_redirect_url = get_view_redirect_url( $f_id, 1 );
 	if ( $result ) {
-		print_meta_redirect( $t_redirect_url );
+		print_header_redirect( $t_redirect_url );
+	} else {
+		print_mantis_error( ERROR_GENERIC );
 	}
-?>
-<?php print_page_top2() ?>
-
-<?php print_proceed( $result, $query, $t_redirect_url ) ?>
-
-<?php print_page_bot1( __FILE__ ) ?>
\ No newline at end of file
+?>
\ No newline at end of file
