@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -14,9 +14,6 @@
 	db_connect( $g_hostname, $g_db_username, $g_db_password, $g_database_name );
 	project_access_check( $f_id );
 	check_access( REPORTER );
-
-	# $f_bug_id is the bug id
-	# @@@ What does this do?
 	check_bugnote_exists( $f_id );
 
 	# grab the bugnote text id
@@ -30,25 +27,19 @@
 	$query = "DELETE
 			FROM $g_mantis_bugnote_table
 			WHERE id='$f_bugnote_id'";
-	$result = db_query($query);
+	$result = db_query( $query );
 
 	# Remove the bugnote text
 	$query = "DELETE
 			FROM $g_mantis_bugnote_text_table
 			WHERE id='$t_bugnote_text_id'";
-	$result = db_query($query);
+	$result = db_query( $query );
 
 	# Determine which view page to redirect back to.
 	$t_redirect_url = get_view_redirect_url( $f_id );
-?>
-<?php print_page_top1() ?>
-<?php
 	if ( $result ) {
-		print_meta_redirect( $t_redirect_url );
+		print_header_redirect( $t_redirect_url );
+	} else {
+		print_mantis_error( ERROR_GENERIC );
 	}
-?>
-<?php print_page_top2() ?>
-
-<?php print_proceed( $result, $query, $t_redirect_url ) ?>
-
-<?php print_page_bot1( __FILE__ ) ?>
\ No newline at end of file
+?>
\ No newline at end of file
