@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the files README and LICENSE for details
 
@@ -60,14 +60,7 @@
 	# If the handler is assigned then we add that.
 
 	# The next part is only for NEW bugs.
-	# We go through the assigned project users and grab everyone who is a
-	# DEVELOPER or higher and add that to a user_id array.  We also add the
-	# emails to the email address array.  Then we check the mantis_user_table
-	# and grab anyone who should have automatic access.
-	# This way we don't accidentally grab a normal developer who is set to be
-	# lower for a specific project.  The check_duplicates function should prevent
-	# duplicate entries from being entered
-
+	# We add all ADMINISTRATORs then add DEVELOPERs.
 	# Lastly, we do a bit of post processing and return the bcc string.
 	function build_bcc_list( $p_bug_id, $p_notify_type ) {
 		global $g_mantis_bug_table, $g_mantis_user_table,
@@ -75,133 +68,180 @@
 				$g_project_cookie_val,
 				$g_mantis_project_user_list_table,
 				$g_notify_developers_on_new,
-				$g_use_bcc, $g_use_phpMailer;
+				$g_use_bcc, $g_use_phpMailer,
+				$g_mantis_bug_monitor_table;
 
 		# setup the array of email entries
 		$send_arr = array();
-		$send_counter = 0;
-
-		# Get Reporter and Handler IDs
-		$query = "SELECT reporter_id, handler_id
-		    FROM $g_mantis_bug_table
-		    WHERE id='$p_bug_id'";
-		$result = db_query( $query );
-		$row = db_fetch_array( $result );
-		extract( $row, EXTR_PREFIX_ALL, "v" );
 
 		# Get Reporter Email
+		$v_reporter_id = get_bug_field( $p_bug_id, "reporter_id" );
 		$t_notify_reporter = get_user_pref_info( $v_reporter_id, $p_notify_type );
-		$t_reporter_email = get_user_info( $v_reporter_id, "email" );
-		if ( 1 == $t_notify_reporter ) {
-			$send_arr[$send_counter++] = $t_reporter_email;
+		if ( ON == $t_notify_reporter ) {
+			$send_arr[] = get_user_info( $v_reporter_id, "email" );
 		}
 
 		# Get Handler Email
+		$v_handler_id = get_bug_field( $p_bug_id, "handler_id" );
 		if ( $v_handler_id > 0 ) {
-			$t_handler_email = get_user_info( $v_handler_id, "email" );
 			$t_notify_handler = get_user_pref_info( $v_handler_id, $p_notify_type );
-
-			if ( 1 == $t_notify_handler ) {
-				if (!check_duplicate($send_arr,$t_handler_email) ) {
-					$send_arr[$send_counter++] = $t_handler_email;
-				}
+			if ( ON == $t_notify_handler ) {
+				$send_arr[] = get_user_info( $v_handler_id, "email" );
 			}
 		}
 
-		# Get Developer Email
+		# Check if we want to broadcast to all developers on a NEW bug
 		if ( ( ON == $g_notify_developers_on_new )&&( "email_on_new" == $p_notify_type ) ) {
-			$user_id_arr = array();
-			$user_id_counter = 0;
-			$p_project_id = get_bug_project_id( $p_bug_id );
+			$t_project_id = get_bug_field( $p_bug_id, "project_id" );
+			$t_project_view_state = get_project_field( $g_project_cookie_val, "view_state" );
 			$t_dev = DEVELOPER;
+			$t_adm = ADMINISTRATOR;
+			$t_public = PUBLIC;
+
+			#@@@@@@@
+			$temp_arr = array();
+			# grab the administrators
+			$query = "SELECT id, email
+					FROM $g_mantis_user_table
+					ORDER BY username";
+			$result = db_query( $query );
+			$user_count = db_num_rows( $result );
+			for ($i=0;$i<$user_count;$i++) {
+				$row = db_fetch_array( $result );
+				extract( $row, EXTR_PREFIX_ALL, "v" );
+				$temp_arr[$v_email] = array( $v_email, $v_id );
+			}
+
+			foreach ( $temp_arr as $key => $val ) {
+				$v_id = $val[1];
+				$v_email = $val[0];
+
+				# always add all administrators
+				$t_access_level = get_user_field( $v_id, "access_level" );
+				if ( ADMINISTRATOR == $t_access_level ) {
+					$send_arr[] = $v_email;
+					continue;
+				}
+
+				# see if users belong
+				$t_project_view_state = get_project_field( $g_project_cookie_val, "view_state" );
+				if ( PUBLIC == $t_project_view_state ) {
+					$query = "SELECT l.access_level
+							FROM	$g_mantis_project_user_list_table l,
+									$g_mantis_project_table p
+							WHERE	l.project_id='$t_project_id' AND
+									p.id=l.project_id AND
+									l.user_id='$v_id'";
+					$result = db_query( $query );
+					$count = db_num_rows( $result );
+					if ( $count > 0 ){
+						$t_access_level = db_result( $result );
+					}
+					if ( $t_access_level >= DEVELOPER ) {
+						$send_arr[] = $v_email;
+					}
+
+				} else {
+					$query = "SELECT COUNT(*)
+							FROM	$g_mantis_project_user_list_table l,
+									$g_mantis_project_table p
+							WHERE	l.project_id='$t_project_id' AND
+									p.id=l.project_id AND
+									l.user_id='$v_id' AND
+									l.access_level>='$t_dev'";
+					$result = db_query( $query );
+					$count = db_result( $result, 0, 0 );
+					if ( $count > 0 ) {
+						$send_arr[] = $v_email;
+						continue;
+					}
+				}
+			}
+			/*#@@@@@@@@@@@@
+			# grab all the ADMINISTRATORS
+			$query = "SELECT DISTINCT id, email
+					FROM $g_mantis_user_table
+					WHERE access_level>=$t_adm";
+			$result = db_query( $query );
+			$admin_count = db_num_rows( $result );
+			for ($i=0;$i<$admin_count;$i++) {
+				$row = db_fetch_array( $result );
+				$t_notify = get_user_pref_info( $row["id"], $p_notify_type );
+				if ( ON == $t_notify ) {
+					$send_arr[] = $row["email"];
+				}
+			} # end ADMINISTRATORS
+
+			# grab all DEVELOPERs if the project is public
+			# Otherwise check the project user lists
+			if ( PUBLIC == $t_project_view_state ) {
+				$query = "SELECT DISTINCT id as user_id, email
+						FROM $g_mantis_user_table
+						WHERE access_level>=$t_dev";
+			} else {
+				$query = "SELECT DISTINCT p.user_id, u.email
+						FROM $g_mantis_project_user_list_table p,
+							$g_mantis_user_table u
+						WHERE p.project_id=$t_project_id AND
+								p.access_level>=$t_dev AND
+								p.user_id=u.id";
+			}
+
+			# grab all users to mail
+			$query = "SELECT DISTINCT u.id, u.email
+					FROM 	$g_mantis_user_table u,
+							$g_mantis_project_user_list_table l,
+							$g_mantis_project_table p
+					WHERE	u.access_level>=$t_adm OR
+							(p.view_state=$t_public AND
+							p.id=$g_project_cookie_val AND
+							u.access_level>=$t_dev) OR
+							(u.id=l.user_id AND
+							l.project_id=$g_project_cookie_val AND
+							l.access_level>=$t_dev)
+					ORDER BY u.username";
 
-			# Project specific developers
-			# All assigned users that are develoeprs and higher whose accounts are enabled
-/*			$query = "SELECT DISTINCT t1.id, t1.username
-					FROM $g_mantis_user_table as t1
-					LEFT JOIN $g_mantis_project_user_list_table as t2
-					ON t1.id=t2.user_id
-					WHERE (t2.access_level>=55 AND t2.project_id=2) OR
-						  (t1.access_level>=55 AND t2.access_level IS NULL)
-					ORDER BY t1.username";
-*/
-			$query = "SELECT DISTINCT p.user_id
-					FROM $g_mantis_project_user_list_table p,
-						$g_mantis_user_table u
-					WHERE p.project_id=$p_project_id AND
-							p.access_level>=$t_dev AND
-							p.user_id=u.id AND
-							u.enabled=1";
 			$result = db_query( $query );
 			$proj_user_count = db_num_rows( $result );
 			for ($i=0;$i<$proj_user_count;$i++) {
 				$row = db_fetch_array( $result );
 
 				# if the user's notification is on then add to the list
-				$t_notify = get_user_pref_info( $row["user_id"], $p_notify_type );
-
-				if ( 1 == $t_notify ) {
-					$user_id_arr[$user_id_counter++] = $row["user_id"];
-
-					if ( !check_duplicate( $send_arr,get_user_info( $row["user_id"], "email" ) ) ) {
-						$send_arr[$send_counter++] = get_user_info( $row["user_id"], "email" );
-					}
-				}
-			}
-
-			# Grab the minimum access threshold for this project
-			$query = "SELECT access_min, view_state
-					FROM $g_mantis_project_table
-					WHERE id='$g_project_cookie_val'";
-			$result = db_query( $query );
-			$row = db_fetch_array( $result );
-			extract( $row, EXTR_PREFIX_ALL, "v" );
-
-			# Global developer role
-			if ( PRIVATE == $v_view_state ) {
-				$query = "SELECT id
-							FROM $g_mantis_user_table
-							WHERE access_level>=$v_access_min AND
-									enabled=1";
-			} else {
-				$query = "SELECT id
-							FROM $g_mantis_user_table
-							WHERE access_level>=$t_dev AND
-									enabled=1";
-			}
-			$result = db_query( $query );
-
-			$user_count = db_num_rows( $result );
-			for ($i=0;$i<$user_count;$i++) {
-				$row = db_fetch_array( $result );
-
 				$t_notify = get_user_pref_info( $row["id"], $p_notify_type );
-				$found = 0;
-				if ( 1 == $t_notify ) {
-					for ($k=0;$k<count( $user_id_arr );$k++) {
-						if ( $user_id_arr[$k] == $row["id"] ) {
-							$found = 1;
-							break;
-						}
-					}
-					if ( $found == 0 ) {
-						if ( !check_duplicate( $send_arr, get_user_info( $row["id"], "email" ) ) ) {
-							$send_arr[$send_counter++] = get_user_info( $row["id"], "email" );
-						}
-					}
+				if ( ON == $t_notify ) {
+					$send_arr[] = $row["email"];
 				}
-			}
-		}
+			} # end DEVELOPERS*/
+		} # end NEW bug developer section
 
-		$t_bcc = ($g_use_bcc && !$g_use_phpMailer) ? "Bcc: " : "";
+		# grab all users MONITORING bug
+		$query = "SELECT DISTINCT m.user_id, u.email
+				FROM $g_mantis_bug_monitor_table m,
+					$g_mantis_user_table u
+				WHERE m.bug_id=$p_bug_id AND
+						m.user_id=u.id";
+		$result = db_query( $query );
+		$monitor_user_count = db_num_rows( $result );
+		for ($i=0;$i<$monitor_user_count;$i++) {
+			$row = db_fetch_array( $result );
+
+			# if the user's notification is on then add to the list
+			$t_notify = get_user_pref_info( $row["user_id"], $p_notify_type );
+			if ( ON == $t_notify ) {
+				$send_arr[] = $row["email"];
+			}
+		} # end MONITORING
+
+		$t_bcc = ( $g_use_bcc && !$g_use_phpMailer ) ? "Bcc: " : "";
 		## win-bcc-bug
 
-		for ($i=0; $i<count($send_arr); $i++) {
-			$t_bcc .= $send_arr[$i].", ";
+		$send_arr = array_unique( $send_arr );
+		foreach ( $send_arr as $send_val ) {
+			$t_bcc .= $send_val.", ";
 		}
 
 		# chop off the last comma and add a \n
-		if ( strlen( $t_bcc )>5 ) {
+		if ( strlen( $t_bcc ) > 5 ) {
 			return substr( $t_bcc, 0, strlen( $t_bcc )-2).(($g_use_bcc) ? "\n" : "");  ## win-bcc-bug
 		} else {
 			return "";
@@ -328,11 +368,8 @@
 				$s_email_duplicate, $s_email_date_submitted,
 				$s_email_last_modified, $s_email_summary,
 				$s_email_description,
-				$s_resolution_enum_string,
-				$s_severity_enum_string,
-				$s_priority_enum_string,
-				$s_status_enum_string,
-				$s_reproducibility_enum_string;
+				$g_email_separator1,
+				$g_email_padding_length;
 
 		$query = "SELECT *, UNIX_TIMESTAMP(date_submitted) as date_submitted,
 				UNIX_TIMESTAMP(last_updated) as last_updated
@@ -364,37 +401,37 @@
 		$v_date_submitted = date( $g_complete_date_format, $v_date_submitted );
 		$v_last_updated   = date( $g_complete_date_format, $v_last_updated );
 
-		$t_sev_str = get_enum_element( $s_severity_enum_string, $v_severity );
-		$t_pri_str = get_enum_element( $s_priority_enum_string, $v_priority );
-		$t_sta_str = get_enum_element( $s_status_enum_string, $v_status );
-		$t_rep_str = get_enum_element( $s_reproducibility_enum_string, $v_reproducibility );
-		$t_message = "=======================================================================\n";
+		$t_sev_str = get_enum_element( "severity", $v_severity );
+		$t_pri_str = get_enum_element( "priority", $v_priority );
+		$t_sta_str = get_enum_element( "status", $v_status );
+		$t_rep_str = get_enum_element( "reproducibility", $v_reproducibility );
+		$t_message = $g_email_separator1."\n";
 		$t_message .= $g_view_bug_page."?f_id=".$p_bug_id."\n";
-		$t_message .= "=======================================================================\n";
-		$t_message .= str_pd( $s_email_reporter.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$t_reporter_name."\n";
-		$t_message .= str_pd( $s_email_handler.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$t_handler_name."\n";
-		$t_message .= "=======================================================================\n";
-		$t_message .= str_pd( $s_email_project.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$t_project_name."\n";
-		$t_message .= str_pd( $s_email_bug.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$v_id."\n";
-		$t_message .= str_pd( $s_email_category.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$v_category."\n";
-		$t_message .= str_pd( $s_email_reproducibility.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$t_rep_str."\n";
-		$t_message .= str_pd( $s_email_severity.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$t_sev_str."\n";
-		$t_message .= str_pd( $s_email_priority.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$t_pri_str."\n";
-		$t_message .= str_pd( $s_email_status.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$t_sta_str."\n";
+		$t_message .= $g_email_separator1."\n";
+		$t_message .= str_pd( $s_email_reporter.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$t_reporter_name."\n";
+		$t_message .= str_pd( $s_email_handler.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$t_handler_name."\n";
+		$t_message .= $g_email_separator1."\n";
+		$t_message .= str_pd( $s_email_project.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$t_project_name."\n";
+		$t_message .= str_pd( $s_email_bug.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$v_id."\n";
+		$t_message .= str_pd( $s_email_category.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$v_category."\n";
+		$t_message .= str_pd( $s_email_reproducibility.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$t_rep_str."\n";
+		$t_message .= str_pd( $s_email_severity.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$t_sev_str."\n";
+		$t_message .= str_pd( $s_email_priority.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$t_pri_str."\n";
+		$t_message .= str_pd( $s_email_status.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$t_sta_str."\n";
 		if ( RESOLVED == $v_status ) {
-			$t_res_str = get_enum_element( $s_resolution_enum_string, $v_resolution );
-			$t_message .= str_pd( $s_email_resolution.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$t_res_str."\n";
+			$t_res_str = get_enum_element( "resolution", $v_resolution );
+			$t_message .= str_pd( $s_email_resolution.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$t_res_str."\n";
 			if ( DUPLICATE == $v_resolution ) {
-				$t_message .= str_pd( $s_email_duplicate.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$v_duplicate_id."\n";
+				$t_message .= str_pd( $s_email_duplicate.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$v_duplicate_id."\n";
 			}
 		}
-		$t_message .= "=======================================================================\n";
-		$t_message .= str_pd( $s_email_date_submitted.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$v_date_submitted."\n";
-		$t_message .= str_pd( $s_email_last_modified.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$v_last_updated."\n";
-		$t_message .= "=======================================================================\n";
-		$t_message .= str_pd( $s_email_summary.": ", " ", EMAIL_PAD_LENGTH, STR_PAD_RIGHT ).$v_summary."\n";
+		$t_message .= $g_email_separator1."\n";
+		$t_message .= str_pd( $s_email_date_submitted.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$v_date_submitted."\n";
+		$t_message .= str_pd( $s_email_last_modified.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$v_last_updated."\n";
+		$t_message .= $g_email_separator1."\n";
+		$t_message .= str_pd( $s_email_summary.": ", " ", $g_email_padding_length, STR_PAD_RIGHT ).$v_summary."\n";
 		$t_message .= "$s_email_description: \n".wordwrap( $v2_description )."\n";
-		$t_message .= "=======================================================================\n\n";
+		$t_message .= $g_email_separator1."\n\n";
 
 		return $t_message;
 	}
@@ -404,7 +441,7 @@
 	function email_build_bugnote_message( $p_bug_id ) {
 		global 	$g_mantis_bugnote_table, $g_mantis_bugnote_text_table,
 				$g_mantis_user_table, $g_complete_date_format,
-				$g_bugnote_order;
+				$g_bugnote_order, $g_email_separator2;
 
 		$t_message = "";
 
@@ -431,12 +468,11 @@
 			$t_note = string_email( $t_note );
 			$t_last_modified = date( $g_complete_date_format, $t_last_modified );
 			$t_string = " ".$t_username." - ".$t_last_modified." ";
-			$t_message = $t_message."-----------------------------------------------------------------------\n";
+			$t_message = $t_message.$g_email_separator2."\n";
 			$t_message = $t_message.$t_string."\n";
-			$t_message = $t_message."-----------------------------------------------------------------------\n";
+			$t_message = $t_message.$g_email_separator2."\n";
 			$t_message = $t_message.wordwrap( $t_note )."\n\n";
 		}
-
 		return $t_message;
 	}
 	# --------------------
@@ -461,11 +497,11 @@
 		if ( OFF == $g_use_bcc ) {
 			## list of receivers
 			$to = $g_to_email.(($p_headers && $g_to_email) ? ", " : "").$p_headers;
-			# echo "<br>email_bug_info::Sending email to :" . $to;
+			# echo "<br />email_bug_info::Sending email to :" . $to;
 			$res1 = email_send( $to, $p_subject, $t_message, "" );
 		} else {
 			# Send Email
-			# echo "<br>email_bug_info::Sending email to : ".$g_to_email;
+			# echo "<br />email_bug_info::Sending email to : ".$g_to_email;
 			$res1 = email_send( $g_to_email, $p_subject, $t_message, $p_headers );
 		}
 	}
@@ -486,12 +522,12 @@
 		$t_message   = trim( $p_message );
 
 		# for debugging only
-		#echo $t_recipient."<BR>".$t_subject."<BR>".$t_message."<BR>".$t_headers;
+		#echo $t_recipient."<br />".$t_subject."<br />".$t_message."<br />".$t_headers;
 		#exit;
-		#echo "<br>xxxRecipient =".$t_recipient."<br>";
-		#echo "Headers =".nl2br($t_headers)."<br>";
-		#echo $t_subject."<br>";
-		#echo nl2br($t_message)."<br>";
+		#echo "<br />xxxRecipient =".$t_recipient."<br />";
+		#echo "Headers =".nl2br($t_headers)."<br />";
+		#echo $t_subject."<br />";
+		#echo nl2br($t_message)."<br />";
 		#exit;
 
 		if ( ON == $g_use_phpMailer )  {
@@ -517,10 +553,13 @@
 			$mail->From     = $g_from_email;
 			$mail->FromName = "";
 
-			if($t_recipient) {
-				$mail->AddAddress($t_recipient, "");
+			# add to the Recipient list
+			$t_recipient_list = split(",", $t_recipient);
+			while ( list( , $t_recipient ) = each( $t_recipient_list ) ) {
+				if ( !empty( $t_recipient ) ) {
+					$mail->AddAddress( $t_recipient, "" );
+				}
 			}
-
 			# add to the BCC list
 			$t_bcc_list = split(",", $p_header);
 			while(list(, $t_bcc) = each($t_bcc_list)) {
@@ -530,11 +569,11 @@
 			}
 
 			$mail->Subject = $t_subject;
-			$mail->Body    = "\n".$t_message;
+			$mail->Body    = make_lf_crlf( "\n".$t_message );
 
 			if( !$mail->Send() ) {
-				PRINT "PROBLEMS SENDING MAIL TO: $t_recipient<br>";
-				PRINT "Mailer Error: ".$mail->ErrorInfo."<br>";
+				PRINT "PROBLEMS SENDING MAIL TO: $t_recipient<br />";
+				PRINT "Mailer Error: ".$mail->ErrorInfo."<br />";
 				exit;
 			}
 		} else {
@@ -554,12 +593,17 @@
 			# $t_headers .= "Content-Type: text/html; charset=iso-8859-1\n";
 
 			$t_headers .= $p_header;
+
+			$t_recipient = make_lf_crlf( $t_recipient );
+			$t_subject = make_lf_crlf( $t_subject );
+			$t_message = make_lf_crlf( $t_message );
+			$t_headers = make_lf_crlf( $t_headers );
 			$result = mail( $t_recipient, $t_subject, $t_message, $t_headers );
 			if ( TRUE != $result ) {
 				PRINT "PROBLEMS SENDING MAIL TO: $t_recipient<p>";
-				PRINT htmlspecialchars($t_recipient)."<br>";
+				PRINT htmlspecialchars($t_recipient)."<br />";
 				PRINT htmlspecialchars($t_subject)."<p>";
-				PRINT nl2br(htmlspecialchars($t_headers))."<br>";
+				PRINT nl2br(htmlspecialchars($t_headers))."<br />";
 				PRINT nl2br(htmlspecialchars($t_message))."<p>";
 				exit;
 			}
@@ -567,17 +611,6 @@
 	}
 	# --------------------
 	# helper function
-	function get_bug_project_id( $p_bug_id ) {
-		global $g_mantis_bug_table;
-
-		$query = "SELECT project_id
-				FROM $g_mantis_bug_table
-				WHERE id='$p_bug_id'";
-		$result = db_query( $query );
-		return db_result( $result, 0, 0 );
-	}
-	# --------------------
-	# helper function
 	function get_bug_summary( $p_bug_id ) {
 		global $g_mantis_bug_table;
 
@@ -591,8 +624,10 @@
 	# formats the subject correctly
 	# we include the project name, bug id, and summary.
 	function email_build_subject( $p_bug_id ) {
+		global $g_project_cookie_val;
+
 		# grab the project name
-		$p_project_name = get_project_field( ( get_bug_project_id( $p_bug_id ) ), "name" );
+		$p_project_name = get_project_field( $g_project_cookie_val, "name" );
 
 		# grab the subject (summary)
 		$p_subject = string_email( get_bug_summary( $p_bug_id ) );
@@ -603,4 +638,16 @@
 		return "[".$p_project_name." ".$p_bug_id."]: ".$p_subject;
 	}
 	# --------------------
+	# clean up LF to CRLF
+	function make_lf_crlf( $p_string ) {
+		global $g_mail_send_crlf;
+
+		if ( ON == $g_mail_send_crlf ) {
+			$p_string = str_replace( "\n", "\r\n", $p_string );
+			return str_replace( "\r\r\n", "\r\n", $p_string );
+		} else {
+			return $p_string;
+		}
+	}
+	# --------------------
 ?>
