@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the files README and LICENSE for details
 
@@ -31,6 +31,7 @@
 		print_body_top();
 		print_header( $g_page_title );
 		print_top_page( $g_top_include_page );
+		print_login_info();
 		print_menu();
 	}
 	# --------------------
@@ -161,11 +162,14 @@
 	function print_footer( $p_file ) {
 		global 	$g_string_cookie_val, $g_webmaster_email,
 				$g_menu_include_file, $g_show_footer_menu,
-				$g_mantis_version, $g_show_version;
+				$g_mantis_version, $g_show_version,
+				$g_timer, $g_show_timer;
 
+		# @@@
 		if (isset($g_string_cookie_val)&&!empty($g_string_cookie_val)) {
 			if ( $g_show_footer_menu ) {
-				print_bottom_menu( $g_menu_include_file );
+				PRINT "<p>";
+				print_menu();
 			}
 		}
 
@@ -174,10 +178,14 @@
 		PRINT "<p>";
 		PRINT "<hr size=\"1\">";
 		if ( ON == $g_show_version ) {
-			PRINT "<span class=\"italic\"><a href=\"http://mantisbt.sourceforge.net/\">Mantis $g_mantis_version</a></span>";
+			PRINT "<span class=\"timer\"><a href=\"http://mantisbt.sourceforge.net/\">Mantis $g_mantis_version</a></span>";
 		}
-		PRINT "<address>Copyright (C) 2000, 2001</address>";
+		PRINT "<address>Copyright (C) 2000 - 2002</address>";
 		PRINT "<address><a href=\"mailto:$g_webmaster_email\">$g_webmaster_email</a></address>";
+		if ( ON == $g_show_timer ) {
+			$g_timer->end_time();
+			PRINT "<span class=\"italic\">Time: ".$g_timer->elapsed_time()." seconds</span><br />";
+		}
 	}
 	# --------------------
 	# (12)
@@ -196,31 +204,32 @@
 	# --------------------
 	# prints the user that is logged in and the date/time
 	# it also creates the form where users can switch projects
-	# this is used by print_menu()
 	function print_login_info() {
 		global 	$g_mantis_user_table,
 				$g_string_cookie_val, $g_project_cookie_val,
 				$g_complete_date_format, $g_set_project,
-				$s_switch, $s_logged_in_as, $s_all_projects;
+				$s_switch, $s_logged_in_as, $s_all_projects,
+				$s_access_levels_enum_string;
 
 		$t_username = get_current_user_field( "username" );
+		$t_access_level = get_enum_element( "access_levels", get_current_user_access_level() );
 		$t_now = date( $g_complete_date_format );
 
 		PRINT "<table class=\"hide\">";
 		PRINT "<form method=\"post\" action=\"$g_set_project\">";
 		PRINT "<tr>";
 			PRINT "<td class=\"login-info-left\">";
-				PRINT "$s_logged_in_as: <span class=\"login-username\">$t_username</span>";
+				PRINT "$s_logged_in_as: <span class=\"login-username\">$t_username</span> <span class=\"small\">($t_access_level)</span>";
 			PRINT "</td>";
 			PRINT "<td class=\"login-info-middle\">";
 				PRINT "<span class=\"login-time\">$t_now</span>";
 			PRINT "</td>";
 			PRINT "<td class=\"login-info-right\">";
-				PRINT "<select name=f_project_id>";
+				PRINT "<select name=\"f_project_id\" class=\"small\">";
 					PRINT "<option value=\"0000000\">$s_all_projects</option>";
 					print_project_option_list( $g_project_cookie_val );
 				PRINT "</select>";
-				PRINT "<input type=\"submit\" value=\"$s_switch\">";
+				PRINT "<input type=\"submit\" value=\"$s_switch\" class=\"small\">";
 			PRINT "</td>";
 		PRINT "</tr>";
 		PRINT "</form>";
@@ -229,7 +238,7 @@
 	# --------------------
 	# This prints the little [?] link for user help
 	# The $p_a_name is a link into the documentation.html file
-	function print_documentaion_link( $p_a_name="" ) {
+	function print_documentation_link( $p_a_name="" ) {
 		global $g_documentation_html;
 
 		PRINT "<a href=\"$g_documentation_html#$p_a_name\" target=_info>[?]</a>";
@@ -279,17 +288,18 @@
 				$s_main_link, $s_view_bugs_link, $s_report_bug_link,
 				$s_summary_link, $s_account_link, $g_manage_project_menu_page,
 				$s_manage_link, $s_users_link, $s_edit_news_link, $s_docs_link,
+				$s_jump, $g_jump_to_bug,
+
 				$s_logout_link;
 
 		if ( isset( $g_string_cookie_val ) ) {
-			print_login_info();
-
 		    $t_protected = get_current_user_field( "protected" );
 			PRINT "<table class=\"width100\" cellspacing=\"0\">";
 			PRINT "<tr>";
 				PRINT "<td class=\"menu\">";
 				PRINT "<a href=\"$g_main_page\">$s_main_link</a> | ";
 				PRINT "<a href=\"$g_view_all_bug_page\">$s_view_bugs_link</a> | ";
+				$t_project_status = get_project_field( $g_project_cookie_val, "status" );
 				if ( access_level_check_greater_or_equal( REPORTER ) ) {
 					if ( "0000000" != $g_project_cookie_val ) {
 						$t_report_url = get_report_redirect_url( 1 );
@@ -300,7 +310,12 @@
 				}
 
 				PRINT "<a href=\"$g_summary_page\">$s_summary_link</a> | ";
-				PRINT "<a href=\"$g_account_page\">$s_account_link</a> | ";
+
+				# only show accounts that are NOT protected
+				if ( OFF == $t_protected ) {
+					PRINT "<a href=\"$g_account_page\">$s_account_link</a> | ";
+				}
+
 				if ( access_level_check_greater_or_equal( MANAGER ) ) {
 					if ( "0000000" != $g_project_cookie_val ) {
 						PRINT "<a href=\"$g_proj_user_menu_page\">$s_users_link</a> | ";
@@ -313,30 +328,27 @@
 					PRINT "<a href=\"$g_manage_page\">$s_manage_link</a> | ";
 				}
 				if ( access_level_check_greater_or_equal( MANAGER ) ) {
+					if ( "0000000" != $g_project_cookie_val ) {
 					PRINT "<a href=\"$g_news_menu_page\">$s_edit_news_link</a> | ";
+					} else {
+						PRINT "<a href=\"$g_login_select_proj_page\">$s_edit_news_link</a> | ";
+					}
 				}
 
 				PRINT "<a href=\"$g_proj_doc_page\">$s_docs_link</a> | ";
 				PRINT "<a href=\"$g_logout_page\">$s_logout_link</a>";
-			PRINT "</td>";
+				PRINT "</td>";
+				PRINT "<form method=\"post\" action=\"$g_jump_to_bug\">";
+				PRINT "<td nowrap class=\"right\">";
+				PRINT "<input type=\"text\" name=\"f_id\" size=\"10\" class=\"small\">&nbsp;";
+				PRINT "<input type=\"submit\" value=\"$s_jump\" class=\"small\">&nbsp;";
+				PRINT "</td>";
+				PRINT "</form>";
 			PRINT "</tr>";
 			PRINT "</table>";
 		}
 	}
 	# --------------------
-	# this is the same as print_menu except without the login info
-	# this is set by setting $g_show_footer_menu to 1
-	function print_bottom_menu( $p_menu_file="" ) {
-		PRINT "<p>";
-		PRINT "<table class=\"menu\" cellspacing=\"0\">";
-		PRINT "<tr>";
-			PRINT "<td class=\"menu\">";
-				include( $p_menu_file );
-			PRINT "</td>";
-		PRINT "</tr>";
-		PRINT "</table>";
-	}
-	# --------------------
 	# prints the manage menu
 	# if the $p_page matches a url then don't make that a link
 	function print_manage_menu( $p_page="" ) {
@@ -416,25 +428,22 @@
 	# prints the manage doc menu
 	# if the $p_page matches a url then don't make that a link
 	function print_manage_doc_menu( $p_page="" ) {
-		global	$g_site_settings_page, $s_site_settings_link,
-				$g_documentation_page, $s_system_info_link;
+		global	$g_documentation_page, $s_system_info_link, $g_path;
 
+		$g_path = $g_path."doc/";
 		$t_documentation_page = $g_documentation_page;
-		$t_site_settings_page = $g_site_settings_page;
 
 		switch ( $p_page ) {
 			case $t_documentation_page: $t_documentation_page = ""; break;
-			case $t_site_settings_page: $t_site_settings_page = ""; break;
 		}
 
 		PRINT "<p><div align=\"center\">";
 			print_bracket_link( $t_documentation_page, $s_system_info_link );
-			print_bracket_link( $t_site_settings_page, $s_site_settings_link );
-			print_bracket_link( "ChangeLog", "ChangeLog" );
-			print_bracket_link( "README", "README" );
-			print_bracket_link( "INSTALL", "INSTALL" );
-			print_bracket_link( "UPGRADING", "UPGRADING" );
-			print_bracket_link( "CONFIGURATION", "CONFIGURATION" );
+			print_bracket_link( $g_path."ChangeLog", "ChangeLog" );
+			print_bracket_link( $g_path."README", "README" );
+			print_bracket_link( $g_path."INSTALL", "INSTALL" );
+			print_bracket_link( $g_path."UPGRADING", "UPGRADING" );
+			print_bracket_link( $g_path."CUSTOMIZATION", "CUSTOMIZATION" );
 		PRINT "</div>";
 	}
 	# --------------------
@@ -488,4 +497,43 @@
 		PRINT "</div>";
 	}
 	# --------------------
+	# This is our generic error printing function
+	# Errors should terminate the script immediately
+	function print_mantis_error( $p_error_num=0 ) {
+		global $MANTIS_ERROR;
+
+		PRINT "<html><head></head><body>";
+		PRINT $MANTIS_ERROR[$p_error_num];
+		PRINT "</body></html>";
+		exit;
+	}
+	# --------------------
+	# Print the color legend for the colors
+	function print_status_colors() {
+		global	$g_status_enum_string,
+				$g_new_color, $g_feedback_color,
+				$g_acknowledged_color, $g_confirmed_color,
+				$g_assigned_color, $g_resolved_color,
+				$g_closed_color;
+
+		PRINT "<p>";
+		PRINT "<table class=\"width100\" cellspacing=\"1\">";
+		PRINT "<tr>";
+		$t_arr  = explode_enum_string( $g_status_enum_string );
+		$enum_count = count( $t_arr );
+		for ($i=0;$i<$enum_count;$i++) {
+			$t_s = explode_enum_arr( $t_arr[$i] );
+			$t_val = get_enum_element( "status", $t_s[0] );
+
+			$t_color = "#ffffff";
+			$t_color_variable_name = "g_".$t_s[1]."_color";
+			if ( isset( $$t_color_variable_name ) ) {
+				$t_color = $$t_color_variable_name;
+			}
+			PRINT "<td class=\"small-caption\" bgcolor=\"$t_color\">$t_val</td>";
+		}
+		PRINT "</tr>";
+		PRINT "</table>";
+	}
+	# --------------------
 ?>
