@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the files README and LICENSE for details
 
@@ -26,6 +26,7 @@
 		} else {
 			header( "Location: $p_url" );
 		}
+		die; # additional output can cause problems so let's just stop output here
 	}
 	# --------------------
 	# prints the name of the user given the id.  also makes it an email link.
@@ -105,59 +106,122 @@
 	# Option List Printing API
 	###########################################################################
 	# --------------------
-	function print_user_option_list( $p_user_id ) {
-		global $g_mantis_user_table;
-
-	    $query = "SELECT id, username
-	    		FROM $g_mantis_user_table
-	    		ORDER BY username";
-	    $result = db_query( $query );
-	    $user_count = db_num_rows( $result );
-	    for ($i=0;$i<$user_count;$i++) {
-	    	$row = db_fetch_array( $result );
-	    	$t_user_id   = $row["id"];
-	    	$t_user_name = $row["username"];
-
-	    	if ( $t_user_id == $p_user_id ) {
-				PRINT "<option value=\"$t_user_id\" SELECTED>".$t_user_name."</option>";
-			}
-			else {
-				PRINT "<option value=\"$t_user_id\">".$t_user_name."</option>";
-			}
+	# sorts the array by the first element of the array element
+	# @@@ might not be used
+	function cmp( $p_var1, $p_var2 ) {
+		if ( $p_var1[0][0] == $p_var2[0][0] ) {
+			return 0;
+		}
+		if ( $p_var1[0][0] < $p_var2[0][0] ) {
+			return -1;
+		} else {
+			return 1;
 		}
 	}
 	# --------------------
+	# ugly functions  need to be refactored
+	# This populates the reporter option list with the appropriate users
 	function print_reporter_option_list( $p_user_id ) {
-		global $g_mantis_user_table, $g_project_cookie_val, $g_mantis_project_user_list_table;
+		global	$g_mantis_user_table, $g_mantis_project_user_list_table,
+				$g_mantis_project_table, $g_project_cookie_val;
 
+		$t_adm = ADMINISTRATOR;
 		$t_rep = REPORTER;
-	    # checking if it's a per project statistic or all projects
-		# checking if it's a per project statistic or all projects
-		if ($g_project_cookie_val=='0000000') {
-			$specific_where = " ";
+		$t_pub = PUBLIC;
+		$t_prv = PRIVATE;
+		$user_arr = array();
+
+		# checking if it's per project or all projects
+		# 0 is all projects
+		if ( '0000000' == $g_project_cookie_val ) {
+			$query = "SELECT DISTINCT u.id, u.username, u.email
+					FROM 	$g_mantis_user_table u,
+							$g_mantis_project_user_list_table l,
+							$g_mantis_project_table p
+					WHERE	(p.view_state='$t_pub' AND
+							u.access_level>='$t_rep') OR
+							(l.access_level>='$t_rep' AND
+							l.user_id=u.id) OR
+							u.access_level>='$t_adm'
+					ORDER BY u.username";
+			$result = db_query( $query );
+			$user_count = db_num_rows( $result );
+			for ($i=0;$i<$user_count;$i++) {
+				$row = db_fetch_array( $result );
+				extract( $row, EXTR_PREFIX_ALL, "v" );
+				$user_arr[$v_username] = array( $v_username, $v_id );
+			}
 		} else {
-			$specific_where = " (t2.access_level>=$t_rep AND t2.project_id=$g_project_cookie_val) OR ";
+			$temp_arr = array();
+			# grab the administrators
+			$query = "SELECT id, username
+					FROM $g_mantis_user_table
+					ORDER BY username";
+			$result = db_query( $query );
+			$user_count = db_num_rows( $result );
+			for ($i=0;$i<$user_count;$i++) {
+				$row = db_fetch_array( $result );
+				extract( $row, EXTR_PREFIX_ALL, "v" );
+				$temp_arr[$v_username] = array( $v_username, $v_id );
+			}
+
+			foreach ( $temp_arr as $key => $val ) {
+				$v_id = $val[1];
+				$v_username = $val[0];
+
+				# always add all administrators
+				$t_access_level = get_user_field( $v_id, "access_level" );
+				if ( ADMINISTRATOR == $t_access_level ) {
+					$user_arr[$v_username] = array( $v_username, $v_id );
+					continue;
+				}
+
+				# see if users belong
+				$t_project_view_state = get_project_field( $g_project_cookie_val, "view_state" );
+				if ( PUBLIC == $t_project_view_state ) {
+					$query = "SELECT l.access_level
+							FROM	$g_mantis_project_user_list_table l,
+									$g_mantis_project_table p
+							WHERE	l.project_id='$g_project_cookie_val' AND
+									p.id=l.project_id AND
+									l.user_id='$v_id'";
+					$result = db_query( $query );
+					$count = db_num_rows( $result );
+					if ( $count > 0 ){
+						$t_access_level = db_result( $result );
+					}
+					if ( $t_access_level >= REPORTER ) {
+						$user_arr[$v_username] = array( $v_username, $v_id );
+					}
+
+				} else {
+					$query = "SELECT COUNT(*)
+							FROM	$g_mantis_project_user_list_table l,
+									$g_mantis_project_table p
+							WHERE	l.project_id='$g_project_cookie_val' AND
+									p.id=l.project_id AND
+									l.user_id='$v_id' AND
+									l.access_level>='$t_rep'";
+					$result = db_query( $query );
+					$count = db_result( $result, 0, 0 );
+					if ( $count > 0 ) {
+						$user_arr[$v_username] = array( $v_username, $v_id );
+						continue;
+					}
+				}
+			}
 		}
 
-		$query = "SELECT DISTINCT t1.id, t1.username
-				FROM $g_mantis_user_table as t1
-				LEFT JOIN $g_mantis_project_user_list_table as t2
-				ON t1.id=t2.user_id
-				WHERE $specific_where
-					  (t1.access_level>=$t_rep AND t2.access_level IS NULL)
-				ORDER BY t1.username";
-
-		$result = db_query( $query );
-		$user_count = db_num_rows( $result );
-		for ($i=0;$i<$user_count;$i++) {
-			$row = db_fetch_array( $result );
-			extract( $row, EXTR_PREFIX_ALL, "v" );
+		asort( $user_arr );
+		foreach ( $user_arr as $key => $val ) {
+			$v_id = $val[1];
+			$v_username = $val[0];
 			if ( $v_id == $p_user_id ) {
 				PRINT "<option value=\"$v_id\" SELECTED>$v_username</option>";
 			} else {
 				PRINT "<option value=\"$v_id\">$v_username</option>";
 			}
-		} # end for
+		} # end foreach
 	}
 	# --------------------
 	function print_duplicate_id_option_list() {
@@ -209,7 +273,7 @@
 		global $g_mantis_bug_table;
 
 		$t_category_string = get_enum_string( $g_mantis_bug_table, $p_list );
-	    $t_arr = explode( ",", $t_category_string );
+	    $t_arr = explode_enum_string( $t_category_string );
 		$entry_count = count( $t_arr );
 		for ($i=0;$i<$entry_count;$i++) {
 			$t_s = str_replace( "'", "", $t_arr[$i] );
@@ -226,65 +290,136 @@
 		global $g_mantis_user_table, $g_mantis_project_table,
 				$g_mantis_project_user_list_table, $g_project_cookie_val;
 
-		$t_dev = DEVELOPER;
-		$t_man = MANAGER;
 		$t_adm = ADMINISTRATOR;
+		$t_dev = DEVELOPER;
+		$t_pub = PUBLIC;
+		$t_prv = PRIVATE;
+		$user_arr = array();
 
-		# checking if it's a per project statistic or all projects
-		if ($g_project_cookie_val=='0000000') {
-			$specific_where = " ";
+		# checking if it's per project or all projects
+		# 0 is all projects
+		if ( '0000000' == $g_project_cookie_val ) {
+			$query = "SELECT DISTINCT u.id, u.username, u.email
+					FROM 	$g_mantis_user_table u,
+							$g_mantis_project_user_list_table l,
+							$g_mantis_project_table p
+					WHERE	(p.view_state='$t_pub' AND
+							u.access_level>='$t_dev') OR
+							(l.access_level>='$t_dev' AND
+							l.user_id=u.id) OR
+							u.access_level>='$t_adm'
+					ORDER BY u.username";
+			$result = db_query( $query );
+			$user_count = db_num_rows( $result );
+			for ($i=0;$i<$user_count;$i++) {
+				$row = db_fetch_array( $result );
+				extract( $row, EXTR_PREFIX_ALL, "v" );
+				$user_arr[$v_username] = array( $v_username, $v_id );
+			}
 		} else {
-			$specific_where = " (t2.access_level>=$t_dev AND t2.project_id=$g_project_cookie_val) OR ";
+			$temp_arr = array();
+			# grab the administrators
+			$query = "SELECT id, username
+					FROM $g_mantis_user_table
+					ORDER BY username";
+			$result = db_query( $query );
+			$user_count = db_num_rows( $result );
+			for ($i=0;$i<$user_count;$i++) {
+				$row = db_fetch_array( $result );
+				extract( $row, EXTR_PREFIX_ALL, "v" );
+				$temp_arr[$v_username] = array( $v_username, $v_id );
+			}
+
+			foreach ( $temp_arr as $key => $val ) {
+				$v_id = $val[1];
+				$v_username = $val[0];
+
+				# always add all administrators
+				$t_access_level = get_user_field( $v_id, "access_level" );
+				if ( ADMINISTRATOR == $t_access_level ) {
+					$user_arr[$v_username] = array( $v_username, $v_id );
+					continue;
+				}
+
+				# see if users belong
+				$t_project_view_state = get_project_field( $g_project_cookie_val, "view_state" );
+				if ( PUBLIC == $t_project_view_state ) {
+					$query = "SELECT l.access_level
+							FROM	$g_mantis_project_user_list_table l,
+									$g_mantis_project_table p
+							WHERE	l.project_id='$g_project_cookie_val' AND
+									p.id=l.project_id AND
+									l.user_id='$v_id'";
+					$result = db_query( $query );
+					$count = db_num_rows( $result );
+					if ( $count > 0 ){
+						$t_access_level = db_result( $result );
+					}
+					if ( $t_access_level >= DEVELOPER ) {
+						$user_arr[$v_username] = array( $v_username, $v_id );
+					}
+
+				} else {
+					$query = "SELECT COUNT(*)
+							FROM	$g_mantis_project_user_list_table l,
+									$g_mantis_project_table p
+							WHERE	l.project_id='$g_project_cookie_val' AND
+									p.id=l.project_id AND
+									l.user_id='$v_id' AND
+									l.access_level>='$t_dev'";
+					$result = db_query( $query );
+					$count = db_result( $result, 0, 0 );
+					if ( $count > 0 ) {
+						$user_arr[$v_username] = array( $v_username, $v_id );
+						continue;
+					}
+				}
+			}
 		}
 
-		$query = "SELECT DISTINCT t1.id, t1.username
-				FROM $g_mantis_user_table as t1
-				LEFT JOIN $g_mantis_project_user_list_table as t2
-				ON t1.id=t2.user_id
-				WHERE t1.enabled=1 AND
-					  ($specific_where
-					   (t1.access_level>=$t_dev AND t2.access_level IS NULL))
-				ORDER BY t1.username";
-
-		$result = db_query( $query );
-		$user_count = db_num_rows( $result );
-
-		for ($i=0;$i<$user_count;$i++) {
-			$row = db_fetch_array( $result );
-			extract( $row, EXTR_PREFIX_ALL, "v" );
-			if ( $v_id == $p_id ) {
+		asort( $user_arr );
+		foreach ( $user_arr as $key => $val ) {
+			$v_id = $val[1];
+			$v_username = $val[0];
+			if ( $v_id == $p_user_id ) {
 				PRINT "<option value=\"$v_id\" SELECTED>$v_username</option>";
 			} else {
 				PRINT "<option value=\"$v_id\">$v_username</option>";
 			}
-		} # end for
+		} # end foreach
 	}
 	# --------------------
-	# Only list the PUBLIC and ENABLED projects
+	# List projects that the current user has access to
 	function print_project_option_list( $p_project_id="" ) {
 		global $g_mantis_project_table, $g_mantis_project_user_list_table,
 				$g_project_cookie_val;
 
-		$t_access_level = get_current_user_field( "access_level" );
 		$t_user_id = get_current_user_field( "id" );
+		$t_access_level = get_current_user_field( "access_level" );
 
 		$t_pub = PUBLIC;
 		$t_prv = PRIVATE;
 
-		$query = "SELECT DISTINCT( p.id ), p.name
-					FROM $g_mantis_project_table p
-					LEFT JOIN $g_mantis_project_user_list_table u
-					ON p.id=u.project_id
-					WHERE p.enabled=1 AND
-					((p.view_state=$t_pub) OR
-					 (p.view_state=$t_prv AND p.access_min<=$t_access_level) OR
-					 (p.view_state=$t_prv AND u.user_id=$t_user_id))
-					ORDER BY p.name";
+		if ( ADMINISTRATOR == $t_access_level ) {
+			$query = "SELECT DISTINCT( p.id ), p.name
+						FROM $g_mantis_project_table p
+						WHERE p.enabled=1
+						ORDER BY p.name";
+		} else {
+			$query = "SELECT DISTINCT( p.id ), p.name
+						FROM $g_mantis_project_table p
+						LEFT JOIN $g_mantis_project_user_list_table u
+						ON p.id=u.project_id
+						WHERE p.enabled=1 AND
+						((p.view_state=$t_pub) OR
+						 (p.view_state=$t_prv AND u.user_id=$t_user_id))
+						ORDER BY p.name";
+		}
 
 		$result = db_query( $query );
-		$user_count = db_num_rows( $result );
+		$project_count = db_num_rows( $result );
 
-		for ($i=0;$i<$user_count;$i++) {
+		for ($i=0;$i<$project_count;$i++) {
 			$row = db_fetch_array( $result );
 			extract( $row, EXTR_PREFIX_ALL, "v" );
 			if ( $p_project_id == $v_id ) {
@@ -360,13 +495,96 @@
 		} # end for
 	}
 	# --------------------
+	# Since categories can be orphaned we need to grab all unique instances of category
+	# We check in the project category table and in the bug table
+	# We put them all in one array and make sure the entries are unique
 	function print_category_option_list( $p_category="" ) {
-		global $g_mantis_project_category_table, $g_project_cookie_val;
+		global $g_mantis_bug_table, $g_mantis_project_category_table, $g_project_cookie_val;
 
-		$query = "SELECT *
+		# grab all categories in the project category table
+		$cat_arr = array();
+		$query = "SELECT DISTINCT( category ) as category
 				FROM $g_mantis_project_category_table
 				WHERE project_id='$g_project_cookie_val'
 				ORDER BY category";
+		$result = db_query( $query );
+		$category_count = db_num_rows( $result );
+		for ($i=0;$i<$category_count;$i++) {
+			$row = db_fetch_array( $result );
+			$cat_arr[] = $row["category"];
+		}
+		sort( $cat_arr );
+		$cat_arr = array_unique( $cat_arr );
+
+		foreach( $cat_arr as $t_category ) {
+			if ( $t_category == $p_category ) {
+				PRINT "<option value=\"$t_category\" SELECTED>$t_category</option>";
+			} else {
+				PRINT "<option value=\"$t_category\">$t_category</option>";
+			}
+		}
+	}
+	# --------------------
+	# Since categories can be orphaned we need to grab all unique instances of category
+	# We check in the project category table and in the bug table
+	# We put them all in one array and make sure the entries are unique
+	function print_category_complete_option_list( $p_category="" ) {
+		global $g_mantis_bug_table, $g_mantis_project_category_table, $g_project_cookie_val;
+
+		# grab all categories in the project category table
+		$cat_arr = array();
+		$query = "SELECT DISTINCT( category ) as category
+				FROM $g_mantis_project_category_table
+				WHERE project_id='$g_project_cookie_val'
+				ORDER BY category";
+		$result = db_query( $query );
+		$category_count = db_num_rows( $result );
+		for ($i=0;$i<$category_count;$i++) {
+			$row = db_fetch_array( $result );
+			$cat_arr[] = $row["category"];
+		}
+
+		# grab all categories in the bug table
+		$query = "SELECT DISTINCT( category ) as category
+				FROM $g_mantis_bug_table
+				WHERE project_id='$g_project_cookie_val'
+				ORDER BY category";
+		$result = db_query( $query );
+		$category_count = db_num_rows( $result );
+
+		for ($i=0;$i<$category_count;$i++) {
+			$row = db_fetch_array( $result );
+			$cat_arr[] = $row["category"];
+		}
+		sort( $cat_arr );
+		$cat_arr = array_unique( $cat_arr );
+
+		foreach( $cat_arr as $t_category ) {
+			if ( $t_category == $p_category ) {
+				PRINT "<option value=\"$t_category\" SELECTED>$t_category</option>";
+			} else {
+				PRINT "<option value=\"$t_category\">$t_category</option>";
+			}
+		}
+	}
+	# --------------------
+	function print_category_option_listOLD( $p_category="" ) {
+		global $g_mantis_project_category_table, $g_project_cookie_val;
+
+		# @@@ not implemented yet
+		if ( '0000000' == $g_project_cookie_val ) {
+			$query = "SELECT category
+					FROM $g_mantis_project_category_table
+					WHERE project_id='$g_project_cookie_val'
+					ORDER BY category";
+
+		} else {
+			$query = "SELECT category
+					FROM $g_mantis_project_category_table
+					WHERE project_id='$g_project_cookie_val'
+					ORDER BY category";
+		}
+
 		$result = db_query( $query );
 		$category_count = db_num_rows( $result );
 		for ($i=0;$i<$category_count;$i++) {
@@ -400,33 +618,44 @@
 		}
 	}
 	# --------------------
-	function print_enum_string_option_list( $p_enum_string, $p_val=0 ) {
-		$t_arr = explode_enum_string( $p_enum_string);
+	# select the proper enum values based on the input parameter
+	# we use variable variables in order to achieve this
+	function print_enum_string_option_list( $p_enum_name, $p_val=0 ) {
+		$g_var = "g_".$p_enum_name."_enum_string";
+		global $$g_var;
+
+		$t_arr  = explode_enum_string( $$g_var );
 		$enum_count = count( $t_arr );
 		for ($i=0;$i<$enum_count;$i++) {
-			$t_elem = explode_enum_arr( $t_arr[$i] );
+			$t_elem  = explode_enum_arr( $t_arr[$i] );
+			$t_elem2 = get_enum_element( $p_enum_name, $t_elem[0] );
 			if ( $t_elem[0] == $p_val ) {
-				PRINT "<option value=\"$t_elem[0]\" SELECTED>$t_elem[1]</option>";
+				PRINT "<option value=\"$t_elem[0]\" SELECTED>$t_elem2</option>";
 			} else {
-				PRINT "<option value=\"$t_elem[0]\">$t_elem[1]</option>";
+				PRINT "<option value=\"$t_elem[0]\">$t_elem2</option>";
 			}
 		} # end for
 	}
 	# --------------------
-	function print_project_user_option_list( $p_val=0 ) {
-		global $g_mantis_project_table, $s_access_levels_enum_string;
+	# prints the list of access levels exluding ADMINISTRATOR
+	# this is used when adding users to projects
+	function print_project_user_option_list( $p_val ) {
+		global $g_mantis_project_table, $g_access_levels_enum_string;
 
-		$t_arr = explode_enum_string( $s_access_levels_enum_string );
+		$t_arr = explode_enum_string( $g_access_levels_enum_string );
 		$enum_count = count( $t_arr );
 		for ($i=0;$i<$enum_count;$i++) {
 			$t_elem = explode_enum_arr( $t_arr[$i] );
 
-			if ( ADMINISTRATOR == $t_elem[0]  ) { continue; }
+			if ( $t_elem[0] >= ADMINISTRATOR ) {
+				continue;
+			}
 
+			$t_access_level = get_enum_element( "access_levels", $t_elem[0] );
 			if ( $p_val == $t_elem[0] ) {
-				PRINT "<option value=\"$t_elem[0]\" SELECTED>$t_elem[1]</option>";
+				PRINT "<option value=\"$t_elem[0]\" SELECTED>$t_access_level</option>";
 			} else {
-				PRINT "<option value=\"$t_elem[0]\">$t_elem[1]</option>";
+				PRINT "<option value=\"$t_elem[0]\">$t_access_level</option>";
 			}
 		} # end for
 	}
@@ -455,7 +684,84 @@
 
 		$t_count = count( $zook_arr );
 		for ($i=0;$i<$t_count;$i++) {
-			PRINT "<option value=\"".ACTION."\">".$zook_arr[$i]."</option>";
+			PRINT "<option value=\""."\">".$zook_arr[$i]."</option>";
+		}
+	}
+	# --------------------
+	# list of users that are NOT in the specified project
+	# if no project is specified use the current project
+	function print_project_user_list_option_list( $p_project_id=0 ) {
+		global	$g_mantis_project_user_list_table, $g_mantis_user_table,
+				$g_project_cookie_val;
+
+		if ( 0 == $p_project_id ) {
+			$p_project_id = $g_project_cookie_val;
+		}
+		$t_adm = ADMINISTRATOR;
+		$query = "SELECT DISTINCT u.id, u.username
+				FROM $g_mantis_user_table u
+				LEFT JOIN $g_mantis_project_user_list_table p
+				ON p.user_id=u.id AND p.project_id='$p_project_id'
+				WHERE u.access_level<$t_adm AND
+					p.user_id IS NULL AND
+					u.access_level<'$t_adm'
+				ORDER BY u.username";
+		$result = db_query( $query );
+		$category_count = db_num_rows( $result );
+		for ($i=0;$i<$category_count;$i++) {
+			$row = db_fetch_array( $result );
+			$t_username = $row["username"];
+			$t_id = $row["id"];
+			PRINT "<option value=\"$t_id\">$t_username</option>";
+		}
+	}
+	# --------------------
+	# list of projects that a user is NOT in
+	function print_project_user_list_option_list2( $p_user_id ) {
+		global	$g_mantis_project_user_list_table, $g_mantis_project_table;
+
+		$t_prv = PRIVATE;
+		$query = "SELECT DISTINCT p.id, p.name
+				FROM $g_mantis_project_table p
+				LEFT JOIN $g_mantis_project_user_list_table u
+				ON p.id=u.project_id AND u.user_id='$p_user_id'
+				WHERE p.enabled=1 AND
+					p.view_state='$t_prv' AND
+					u.user_id IS NULL
+				ORDER BY p.name";
+		$result = db_query( $query );
+		$category_count = db_num_rows( $result );
+		for ($i=0;$i<$category_count;$i++) {
+			$row = db_fetch_array( $result );
+			$t_project_name = $row["name"];
+			$t_id = $row["id"];
+			PRINT "<option value=\"$t_id\">$t_project_name</option>";
+		}
+	}
+	# --------------------
+	# list of projects that a user is NOT in
+	function print_project_user_list( $p_user_id ) {
+		global	$g_mantis_project_user_list_table, $g_mantis_project_table,
+				$s_remove_link, $g_manage_user_proj_delete;
+
+		$query = "SELECT DISTINCT p.id, p.name, p.view_state, u.access_level
+				FROM $g_mantis_project_table p
+				LEFT JOIN $g_mantis_project_user_list_table u
+				ON p.id=u.project_id
+				WHERE p.enabled=1 AND
+					u.user_id='$p_user_id'
+				ORDER BY p.name";
+		$result = db_query( $query );
+		$category_count = db_num_rows( $result );
+		for ($i=0;$i<$category_count;$i++) {
+			$row = db_fetch_array( $result );
+			$t_project_id = $row["id"];
+			$t_project_name = $row["name"];
+			$t_view_state = $row["view_state"];
+			$t_access_level = $row["access_level"];
+			$t_access_level = get_enum_element( "access_levels", $t_access_level );
+			$t_view_state = get_enum_element( "project_view_state", $t_view_state );
+			PRINT "$t_project_name [$t_access_level] ($t_view_state) [<a class=\"small\" href=\"$g_manage_user_proj_delete?f_project_id=$t_project_id&f_user_id=$p_user_id\">$s_remove_link</a>]<br />";
 		}
 	}
 	# --------------------
@@ -529,13 +835,32 @@
 		}
 	}
 	# --------------------
+	# returns a href link to a bug given an ID
+	# it accounts for the user preference and site override
+	function get_bug_link_plain( $p_id ) {
+		global 	$g_view_bug_page, $g_view_bug_advanced_page, $g_show_view;
+
+		switch ( $g_show_view ) {
+		case BOTH:
+			if ( ON == get_current_user_pref_field( "advanced_view" ) ) {
+				return "$g_view_bug_advanced_page?f_id=$p_id";
+			} else {
+				return "$g_view_bug_page?f_id=$p_id";
+			}
+			break;
+		case SIMPLE_ONLY:
+			return "$g_view_bug_page?f_id=$p_id";
+			break;
+		case ADVANCED_ONLY:
+			return "$g_view_bug_advanced_page?f_id=$p_id";
+			break;
+		}
+	}
+	# --------------------
 	# formats the severity given the status
 	# shows the severity in BOLD if the bug is NOT closed and is of significant severity
 	function print_formatted_severity_string( $p_status, $p_severity ) {
-		global $g_severity_enum_string, $s_severity_enum_string;
-
-		#$t_sev_str = get_enum_element( $g_severity_enum_string, $p_severity );
-		$t_sev_str = get_enum_element( $s_severity_enum_string, $p_severity );
+		$t_sev_str = get_enum_element( "severity", $p_severity );
 		if ( ( ( MAJOR == $p_severity ) ||
 			   ( CRASH == $p_severity ) ||
 			   ( BLOCK == $p_severity ) ) &&
@@ -599,9 +924,10 @@
 	# Link Printing API
 	###########################################################################
 	# --------------------
-	function print_view_bug_sort_link(  $p_page, $p_string, $p_sort_field, $p_sort, $p_dir ) {
-		if ( $p_sort_field == $p_sort ) {
+	function print_view_bug_sort_link( $p_string, $p_sort_field, $p_sort, $p_dir ) {
+		global $g_view_all_set;
 
+		if ( $p_sort_field == $p_sort ) {
 			# we toggle between ASC and DESC if the user clicks the same sort order
 			if ( "ASC" == $p_dir ) {
 				$p_dir = "DESC";
@@ -609,9 +935,26 @@
 				$p_dir = "ASC";
 			}
 
-			PRINT "<a href=\"$p_page?f_sort=$p_sort_field&f_dir=$p_dir&f_save=2\">$p_string</a>";
+			PRINT "<a href=\"$g_view_all_set?f_sort=$p_sort_field&f_dir=$p_dir&f_type=2\">$p_string</a>";
 		} else {
-			PRINT "<a href=\"$p_page?f_sort=$p_sort_field&f_save=2\">$p_string</a>";
+			PRINT "<a href=\"$g_view_all_set?f_sort=$p_sort_field&f_dir=$p_dir&f_type=2\">$p_string</a>";
+		}
+	}
+	# --------------------
+	function print_view_bug_sort_link2( $p_string, $p_sort_field, $p_sort, $p_dir ) {
+		global $g_view_all_set;
+
+		if ( $p_sort_field == $p_sort ) {
+			# we toggle between ASC and DESC if the user clicks the same sort order
+			if ( "ASC" == $p_dir ) {
+				$p_dir = "DESC";
+			} else {
+				$p_dir = "ASC";
+			}
+
+			PRINT "<a href=\"$g_view_all_set?f_sort=$p_sort_field&f_dir=$p_dir&f_type=2&f_print=1\">$p_string</a>";
+		} else {
+			PRINT "<a href=\"$g_view_all_set?f_sort=$p_sort_field&f_dir=$p_dir&f_type=2&f_print=1\">$p_string</a>";
 		}
 	}
 	# --------------------
@@ -640,12 +983,22 @@
 	# --------------------
 	# return the mailto: href string link instead of printing it
 	function get_email_link( $p_email, $p_text ) {
-		global $g_hide_user_email;
+		global $g_show_user_email, $g_anonymous_account;
 
-		if( ON == $g_hide_user_email ){
-			return "$p_text";
-		} else {
-			return "<a href=\"mailto:$p_email\">$p_text</a>";
+		switch ( $g_show_user_email ) {
+			case NONE:	return "$p_text";
+			case ALL:	return "<a href=\"mailto:$p_email\">$p_text</a>";
+			case NO_ANONYMOUS:	if ( get_current_user_field( "username" ) != $g_anonymous_account ) {
+									return "<a href=\"mailto:$p_email\">$p_text</a>";
+								} else {
+									return "$p_text";
+								}
+			case ADMIN_ONLY:	if ( ADMINISTRATOR == get_current_user_field( "access_level" ) ) {
+									return "<a href=\"mailto:$p_email\">$p_text</a>";
+								} else {
+									return "$p_text";
+								}
+			default:	return "$p_text";
 		}
 	}
 	# --------------------
@@ -653,26 +1006,29 @@
 	function print_email_link_with_subject( $p_email, $p_text, $p_bug_id ) {
 		global $g_mantis_bug_table;
 
-		$query = "SELECT summary
-				FROM $g_mantis_bug_table
-				WHERE id='$p_bug_id'";
-		$result = db_query( $query );
-		$t_summary = db_result( $result, 0, 0 );
-		$t_summary = string_email( $t_summary );
-
-		PRINT get_email_link_with_subject( $p_email, $p_text, $t_summary );
+		$t_subject = email_build_subject( $p_bug_id );
+		PRINT get_email_link_with_subject( $p_email, $p_text, $t_subject );
 	}
 	# --------------------
 	# return the mailto: href string link instead of printing it
 	# add subject line
 	function get_email_link_with_subject( $p_email, $p_text, $p_summary ) {
-		global $g_hide_user_email;
+		global $g_show_user_email, $g_anonymous_account;
 
-		if ( ON == $g_hide_user_email ){
-			return "$p_text";
-		} else {
-			$p_summary = mime_encode( $p_summary );
-			return "<a href=\"mailto:$p_email?subject=$p_summary\">$p_text</a>";
+		switch ( $g_show_user_email ) {
+			case NONE:	return "$p_text";
+			case ALL:	return "<a href=\"mailto:$p_email?subject=$p_summary\">$p_text</a>";
+			case NO_ANONYMOUS:	if ( get_current_user_field( "username" ) != $g_anonymous_account ) {
+									return "<a href=\"mailto:$p_email?subject=$p_summary\">$p_text</a>";
+								} else {
+									return "$p_text";
+								}
+			case ADMIN_ONLY:	if ( ADMINISTRATOR == get_current_user_field( "access_level" ) ) {
+									return "<a href=\"mailto:$p_email?subject=$p_summary\">$p_text</a>";
+								} else {
+									return "$p_text";
+								}
+			default:	return "$p_text";
 		}
 	}
 	# --------------------
@@ -731,7 +1087,7 @@
 		for ($i=0;$i<$t_tag_count;$i++) {
 			$tag = preg_replace( $t_filter_from, $t_filter_to, $g_html_tags[$i] );
 
-			$p_string = preg_replace( "/&lt;($tag)&gt;/", "<\\1>", $p_string );
+			$p_string = preg_replace( "/&lt;($tag)&gt;/i", "<\\1>", $p_string );
 		}
 
 		return $p_string;
@@ -801,7 +1157,7 @@
 		$p_string = str_replace( "&lt;", "<",  $p_string );
 		$p_string = str_replace( "&gt;", ">",  $p_string );
 		$p_string = str_replace( "&quot;", "\"",  $p_string );
-		$p_string = str_replace( "&amp;", "\"",  $p_string );
+		$p_string = str_replace( "&amp;", "&",  $p_string );
 
 		return $p_string;
 	}
