@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the files README and LICENSE for details
 
@@ -129,6 +129,8 @@
 	# Checks for password match using the globally specified login method
 	function is_password_match( $f_username, $p_test_password, $p_password ) {
 		global $g_login_method, $g_allow_anonymous_login, $g_anonymous_account;
+		global $PHP_AUTH_PW;
+
 
 		# allow anonymous logins
 		if ( $g_anonymous_account == $f_username ) {
@@ -144,6 +146,13 @@
 						} else {
 							return false;
 						}
+			case CRYPT_FULL_SALT:
+						$salt = $p_password;
+						if ( crypt( $p_test_password, $salt ) == $p_password ) {
+							return true;
+						} else {
+							return false;
+						}
 			case PLAIN:	if ( $p_test_password == $p_password ) {
 							return true;
 						} else {
@@ -159,6 +168,9 @@
 						} else {
 							return false;
 						}
+			case BASIC_AUTH:
+					return ( isset( $PHP_AUTH_PW ) && ( $p_test_password == $PHP_AUTH_PW ) );
+
 		}
 		return false;
 	}
@@ -177,13 +189,24 @@
 	function process_plain_password( $p_password ) {
 		global $g_login_method;
 
+		$t_processed_password = $p_password;
 		switch ( $g_login_method ) {
 			case CRYPT:	$salt = substr( $p_password, 0, 2 );
-					return crypt( $p_password, $salt );
-			case PLAIN:	return $p_password;
-			case MD5:	return md5( $p_password );
-			default:	return $p_password;
+						$t_processed_password= crypt( $p_password, $salt );
+						break;
+			case CRYPT_FULL_SALT:
+						$salt = $p_password;
+						$t_processed_password = crypt( $p_password, $salt );
+						break;
+			case PLAIN:	$t_processed_password = $p_password;
+						break;
+			case MD5:	$t_processed_password = md5( $p_password );
+						break;
+			default:	$t_processed_password = $p_password;
+						break;
 		}
+		# cut this off to 32 cahracters which the largest possible string in the database
+		return substr( $t_processed_password, 0, 32 );
 	}
 	# --------------------
 	###########################################################################
@@ -312,7 +335,7 @@
 	###########################################################################
 	# --------------------
 	# check to see if the access level is strictly equal
-	function access_level_check_equal( $p_access_level ) {
+	function access_level_check_equal( $p_access_level, $p_project_id=0 ) {
 		global $g_string_cookie_val;
 
 		if ( !isset( $g_string_cookie_val ) ) {
@@ -320,7 +343,7 @@
 		}
 
 		$t_access_level = get_current_user_field( "access_level" );
-		$t_access_level2 = get_project_access_level();
+		$t_access_level2 = get_project_access_level( $p_project_id );
 
 		if ( $t_access_level2 == $p_access_level ) {
 			return true;
@@ -334,7 +357,7 @@
 	# --------------------
 	# check to see if the access level is equal or greater
 	# this checks to see if the user has a higher access level for the current project
-	function access_level_check_greater_or_equal( $p_access_level ) {
+	function access_level_check_greater_or_equal( $p_access_level, $p_project_id=0 ) {
 		global $g_string_cookie_val;
 
 		# user isn't logged in
@@ -348,7 +371,7 @@
 		}
 
 		$t_access_level = get_current_user_field( "access_level" );
-		$t_access_level2 = get_project_access_level();
+		$t_access_level2 = get_project_access_level( $p_project_id );
 
 		# use the project level access level instead of the global access level
 		# if the project level is not specified then use the global access level
@@ -417,7 +440,9 @@
 		}
 	}
 	# --------------------
-	# Checks to see if the user has access to this project.  If not then log the user out.
+	# Checks to see if the user has access to this project
+	# If not then log the user out
+	# If not logged into the project it attempts to log you into that project
 	function project_access_check( $p_bug_id, $p_project_id="0" ) {
 		global	$g_logout_page, $g_mantis_project_user_list_table,
 				$g_mantis_project_table, $g_mantis_bug_table,
@@ -432,23 +457,20 @@
 		}
 
 		# access_level check
-		$t_project_id = get_bug_field( "project_id", $p_bug_id );
-		$t_user_id = get_current_user_field( "id" );
-		$t_project_access_level = get_project_access_level( $t_project_id );
+		$t_project_id = get_bug_field( $p_bug_id, "project_id" );
+		$t_project_view_state = get_project_field( $t_project_id, "view_state" );
 
-		if ( -1 == $t_project_access_level ) {
-			# user is not in the user lists
-			$t_access_level = get_current_user_field( "access_level" );
-			$t_access_threshold = get_project_field( $t_project_id, "access_min" );
-			if ( $t_access_level >= $t_access_threshold ) {
-				return;
-			} else {
-				print_header_redirect( $g_login_select_proj_page );
-			}
-		} else {
-			# user is in the user lists
-			# being in the lists means they have access
+		# public project accept all users
+		if ( PUBLIC == $t_project_view_state ) {
 			return;
+		} else {
+			# private projects require users to be assigned
+			$t_project_access_level = get_project_access_level( $t_project_id );
+			if ( -1 == $t_project_access_level ) {
+				print_header_redirect( $g_login_select_proj_page );
+			} else {
+				return;
+			}
 		}
 	}
 	# --------------------
@@ -456,16 +478,43 @@
 	# If there is no match then the project cookie will be set to the bug project id
 	# No access check is done.  It is expected to be checked afterwards.
 	function project_check( $p_bug_id ) {
-		global	$g_project_cookie, $g_project_cookie_val, $g_cookie_time_length;
+		global	$g_project_cookie, $g_project_cookie_val, $g_view_all_cookie,
+				$g_cookie_time_length, $g_cookie_path;
 
-		$t_project_id = get_bug_field( "project_id", $p_bug_id );
+		$t_project_id = get_bug_field( $p_bug_id, "project_id" );
 		if ( $t_project_id != $g_project_cookie_val ) {
-			setcookie( $g_project_cookie, $t_project_id, time()+$g_cookie_time_length );
+			setcookie( $g_project_cookie, $t_project_id, time()+$g_cookie_time_length, $g_cookie_path );
+			setcookie( $g_view_all_cookie, '' );
+
 			$t_redirect_url = get_view_redirect_url( $p_bug_id, 1 );
 			print_header_redirect( $t_redirect_url );
 		}
 	}
 	# --------------------
+	# Check to see if the current user has access on the specified project
+	function check_access_to_project( $p_project_id ) {
+		$t_project_view_state = get_project_field( $p_project_id, 'view_state' );
+
+		# Administrators ALWAYS pass.
+		if ( get_current_user_field( 'access_level' ) >= ADMINISTRATOR ) {
+			return;
+		}
+
+		# public project accept all users
+		if ( PUBLIC == $t_project_view_state ) {
+			return;
+		} else {
+			# private projects require users to be assigned
+			$t_project_access_level = get_project_access_level( $p_project_id );
+			# -1 means not assigned, kick them out to the project selection screen
+			if ( -1 == $t_project_access_level ) {
+				print_header_redirect( 'login_select_proj_page.php' );
+			} else { # passed
+				return;
+			}
+		}
+	}
+	# --------------------
 	# return the project access level for the current user/project key pair.
 	# use the project_id if supplied.
 	function get_project_access_level( $p_project_id=0 ) {
@@ -492,22 +541,59 @@
 	# --------------------
 	# Return the project user list access level for the current user/project key pair if it exists.
 	# Otherwise return the default user access level.
-	function get_effective_access_level() {
+	function get_effective_access_level( $p_user_id=0, $p_project_id=-1 ) {
 		global	$g_mantis_project_user_list_table,
 				$g_project_cookie_val;
 
-		$t_user_id = get_current_user_field( "id" );
-		$query = "SELECT access_level
-				FROM $g_mantis_project_user_list_table
-				WHERE user_id='$t_user_id' AND project_id='$g_project_cookie_val'";
+		# use the current user unless otherwise specified
+		if ( 0 == $p_user_id ) {
+			$t_user_id = get_current_user_field( "id" );
+		} else {
+			$t_user_id = $p_user_id;
+		}
+
+		# all projects
+		if ( -1 == $p_project_id ) {
+			$query = "SELECT access_level
+					FROM $g_mantis_project_user_list_table
+					WHERE user_id='$t_user_id' AND project_id='$g_project_cookie_val'";
+		} else if ( 0 == $p_project_id ) {
+			$g_project_cookie_val = p_project_id;
+			$query = "SELECT access_level
+					FROM $g_mantis_project_user_list_table
+					WHERE user_id='$t_user_id'";
+		} else {
+			$query = "SELECT access_level
+					FROM $g_mantis_project_user_list_table
+					WHERE user_id='$t_user_id' AND project_id='$p_project_id'";
+		}
+
 		$result = db_query( $query );
-		if ( db_num_rows( $result )>0 ) {
+		$count = db_num_rows( $result, 0, 0 );
+		if ( $count>0 ) {
 			return db_result( $result, 0, 0 );
 		} else {
-			return get_current_user_field( "access_level" );
+			return get_user_field( $t_user_id, "access_level" );
 		}
 	}
 	# --------------------
+	# check to see if the current user has access to the specified bug.  This assume that the bug exists and 
+	# that the user has access to the project (check_bug_exists() and project_access_check()).
+	function access_bug_check( $p_bug_id, $p_view_state='' ) {
+		global $g_private_bug_threshold;
+
+		if ( empty ( $p_view_state ) ) {
+			$t_view_state = get_bug_field( $p_bug_id, 'view_state' );
+		} else {
+			$t_view_state = (integer)$p_view_state;
+		}
+
+		# Make sure if the bug is private, the logged in user has access to it.
+		if ( ( $t_view_state == PRIVATE ) && !access_level_check_greater_or_equal( $g_private_bug_threshold ) ) {
+			print_header_redirect( 'logout_page.php' );
+		}
+	}
+	# --------------------	
 	###########################################################################
 	# User Information API
 	###########################################################################
@@ -589,7 +675,6 @@
 	# exception for LDAP email
 	function get_user_info( $p_user_id, $p_field ) {
 		global $g_mantis_user_table,$g_use_ldap_email,$g_login_method;
-
 		if ( ( ON == $g_use_ldap_email ) && ( "email" == $p_field  ) ) {
 		    # Find out what username belongs to the p_user_id and ask ldap
 		    return ldap_emailaddy("$p_user_id");
@@ -598,10 +683,46 @@
 		$query = "SELECT $p_field
 				FROM $g_mantis_user_table
 				WHERE id='$p_user_id'";
+
+
 		$result =  db_query( $query );
 		return db_result( $result, 0, 0 );
 
 	}
+	# --------------------
+	# return whether user is monitoring bug for the user id and bug id
+	function check_bug_monitoring( $p_user_id, $p_bug_id ) {
+		global $g_mantis_bug_monitor_table;
+
+		$query = "SELECT user_id
+				FROM $g_mantis_bug_monitor_table
+				WHERE user_id='$p_user_id' AND bug_id='$p_bug_id'";
+
+
+		$result =  db_query( $query );
+		return db_result( $result, 0, 0 );
+
+	}
+	# --------------------
+	# return the specified user field for the user id
+	# exception for LDAP email
+	function get_user_field( $p_user_id, $p_field ) {
+		global $g_mantis_user_table,$g_use_ldap_email,$g_login_method;
+		if ( ( ON == $g_use_ldap_email ) && ( "email" == $p_field  ) ) {
+		    # Find out what username belongs to the p_user_id and ask ldap
+		    return ldap_emailaddy("$p_user_id");
+		}
+
+		$query = "SELECT $p_field
+				FROM $g_mantis_user_table
+				WHERE id='$p_user_id'";
+
+
+		$result =  db_query( $query );
+		return db_result( $result, 0, 0 );
+
+	}
+	# --------------------
 	###########################################################################
 	# Miscellaneous User API
 	###########################################################################
@@ -658,4 +779,23 @@
 	    $result = db_query($query);
 	}
 	# --------------------
-?>
\ No newline at end of file
+	# grabs the access level of the current user
+	# this function accounts for private project and the project user lists
+	function get_current_user_access_level() {
+		global $g_string_cookie_val;
+
+		$t_access_level = get_current_user_field( "access_level" );
+		$t_access_level2 = get_project_access_level();
+
+		if ( $t_access_level >= ADMINISTRATOR ) {
+			return $t_access_level;
+		}
+
+		if ( -1 == $t_access_level2 ) {
+			return $t_access_level;
+		} else {
+			return $t_access_level2;
+		}
+	}
+	# --------------------
+?>
