@@ -45,7 +45,7 @@
 	# requires trailing /
 	$g_icon_path     = $g_path."images/";
 
-	# absolute path to your installation.  *NO* symlinks allowed
+	# absolute path to your installation.  *NO* symlinks allowed (causes problems with file downloads)
 	# requires trailing /
 	$g_absolute_path = "/usr/local/www/data/mantis/";
 
@@ -78,6 +78,10 @@
 	# allow users to signup for their own accounts
 	$g_allow_signup              = ON;
 
+	# if ON users will be sent their password when reset.
+	# if OFF the password will be set to blank.
+	$g_send_reset_password       = ON;
+
 	# allow email notification
 	$g_enable_email_notification = ON;
 
@@ -85,20 +89,26 @@
 	# only if their preference is also set
 	$g_notify_developers_on_new  = ON;
 
-	# set to 0 to disable email check
+	# set to OFF to disable email check
 	$g_validate_email            = ON;
 	$g_check_mx_record           = ON;
 
 	# This disables the automatic generation of mailto: links
-	$g_hide_user_email           = OFF;
+	# Valid values: NONE, ALL, NO_ANONYMOUS, ADMIN_ONLY
+	$g_show_user_email           = NONE;
 
-	# Set to 0 to remove X-Priority header
+	# Set to OFF to remove X-Priority header
 	$g_use_x_priority            = ON;
 
-	# Set to 0 as on Windows systems, as long as php-mail-function has its
-	# bcc-bug (~PHP 4.0.6)
+	# Set to OFF on Windows systems, as long as php-mail-function has its bcc-bug (~PHP 4.0.6)
 	$g_use_bcc                   = ON;
 
+	# some Mail transfer agents (MTAs) don't like bare linefeeds...
+	# or they take good input and create barelinefeeds
+	# If problems occur when sending mail through your server try turning this OFF
+	# more here: http://pobox.com/~djb/docs/smtplf.html
+	$g_mail_send_crlf            = OFF;
+
 	# phpMailer instead of standard mail() function (REQUIRES PHP 4.x.x)
 	# Get the phpMailer-package from http://phpmailer.sourceforge.net
 	# The installation is very simple you only need 2 plain text php-files
@@ -124,12 +134,17 @@
 	# Name of smtp host, needed for phpMailer, taken from php.ini
 	$g_smtp_host     = "localhost";
 
+	# --- email separator and padding ------------
+	$g_email_separator1     = "=======================================================================";
+	$g_email_separator2     = "-----------------------------------------------------------------------";
+	$g_email_padding_length = 28;
+
 	#############################
 	# Mantis Version String
 	#############################
 
 	# --- version variables -----------
-	$g_mantis_version = "0.17.1";
+	$g_mantis_version = "0.17.5";
 	$g_show_version   = ON;
 
 	################################
@@ -137,11 +152,10 @@
 	################################
 
 	# --- language settings -----------
-
 	$g_default_language     = "english";
 
 	# list the choices that the users are allowed to choose
-	$g_language_choices_arr = array( "english", "chinese_traditional", "danish", "dutch", "french", "french2", "german", "italian", "korean", "norwegian", "polish", "portuguese_brazil", "portuguese_standard", "romanian", "russian", "spanish", "swedish", "turkish" );
+	$g_language_choices_arr = array( "english", "chinese_traditional", "czech", "danish", "dutch", "french", "french2", "german", "hungarian", "italian", "japanese_euc", "japanese_sjis", "korean", "norwegian", "polish", "portuguese_brazil", "portuguese_standard", "romanian", "russian", "russian_koi8", "spanish", "swedish", "turkish" );
 
 	###############################
 	# Mantis Display Settings
@@ -315,10 +329,19 @@
 
 	# Upload destination: specify actual location in project settings
 	# DISK or DATABASE
-	$g_file_upload_method   = DISK;
+	$g_file_upload_method   = DATABASE;
 
+	# Maximum file size that can be uploaded
+	# Also check your PHP settings (default is usually 2MBs)
 	$g_max_file_size        = 5000000; # 5 MB
 
+	# Files that are allowed or not allowed.  Separate items by commas.
+	# eg. "php,html,java,exe,pl"
+	# if $g_allowed_files is filled in NO other file types will be allowed.
+	# $g_disallowed_files takes precedence over $g_allowed_files
+	$g_allowed_files     = "";
+	$g_disallowed_files  = "";
+
 	############################
 	# Mantis HTML Settings
 	############################
@@ -369,22 +392,36 @@
 	# Look in the constant_inc.php file if you want to set a different value
 	$g_reopen_bug_threshold = DEVELOPER;
 
-	# --- quick proceed----------------
-	# see fewer confirmation screens between actions
-	$g_quick_proceed = ON;
+	# access level needed to close bugs
+	# Look in the constant_inc.php file if you want to set a different value
+	$g_close_bug_threshold = DEVELOPER;
+
+	# access level needed to monitor bugs
+	# Look in the constant_inc.php file if you want to set a different value
+	$g_monitor_bug_threshold = REPORTER;
+	$g_private_bug_threshold = DEVELOPER;
 
 	# --- login method ----------------
-	# CRYPT or PLAIN or MD5 or LDAP or BASIC_AUTH
+	# CRYPT or CRYPT_FULL_SALT or PLAIN or MD5 or LDAP or BASIC_AUTH
+	# If you were using CRYPT and it now fails, try CRYPT_FULL_SALT
 	$g_login_method = MD5;
 
 	# --- limit reporters -------------
-	# Set to 1 if you wish to limit reporters to only viewing bugs that they report.
+	# Set to ON if you wish to limit reporters to only viewing bugs that they report.
 	$g_limit_reporters = OFF;
 
 	# --- close immediately -----------
 	# Allow developers and above to close bugs immediately when resolving bugs
 	$g_allow_close_immediately = OFF;
 
+	# --- account delete -----------
+	# Allow the specified access level and higher to delete bugs
+	$g_allow_bug_delete_access_level = DEVELOPER;
+
+	# --- move bugs -----------
+	# Allow the specified access level and higher to move bugs between projects
+	$g_bug_move_access_level = DEVELOPER;
+
 	# --- account delete -----------
 	# Allow users to delete their own accounts
 	$g_allow_account_delete = OFF;
@@ -397,6 +434,22 @@
 	# --- CVS linking ---------------
 	# insert the URL to your CVSweb or ViewCVS
 	$g_cvs_web = "http://cvs.sourceforge.net/cgi-bin/viewcvs.cgi/mantisbt/mantisbt/";
+
+	# --- Bug Linking ---------------
+	# if a number follows this tag it will create a link to a bug.
+	# eg. for # a link would be #45
+	# eg. for bug: a link would be bug:98
+	$g_bug_link_tag = "#";
+
+	# --- Timer ----------------------
+	# Time page loads.  Shows at the bottom of the page.
+	$g_show_timer   = OFF;
+
+	# --- register globals -----------
+	# @@@ experimental
+	# if your register_globals is Off then set this to OFF
+	$g_register_globals          = ON;
+
   	################################
 	# Mantis Look and Feel Variables
 	################################
@@ -436,6 +489,15 @@
 	# Mantis Cookie Variables
 	###############################
 
+	# --- cookie path ---------------
+	# set this to something more restrictive if needed
+	# http://www.php.net/manual/en/function.setcookie.php
+	$g_cookie_path = "/";
+	# unused
+	$g_cookie_domain = ".mydomain.extension";
+	# cookie version for view_all_page
+	$g_cookie_version = "v3";
+
 	# --- cookie prefix ---------------
 	# set this to a unique identifier.  No spaces.
 	$g_cookie_prefix = "MANTIS";
@@ -488,6 +550,7 @@
 	$g_mantis_user_table              = $g_db_table_prefix."_user_table";
 	$g_mantis_user_profile_table      = $g_db_table_prefix."_user_profile_table";
 	$g_mantis_user_pref_table         = $g_db_table_prefix."_user_pref_table";
+	$g_mantis_bug_monitor_table       = $g_db_table_prefix."_bug_monitor_table";
 
 	###########################
 	# Mantis Enum Strings
@@ -515,4 +578,13 @@
 	# set this to php for php4 or whatever your webserver needs
 	$g_php             = ".php";
 	#----------------------------------
-?>
\ No newline at end of file
+
+	#############################
+	# Mantis Javascript Variables
+	#############################
+	#----------------------------------
+	# allow the use of Javascript?
+	# @@@ not yet implemented, but wanted this in config for 0.17.2+ -SC
+	$g_use_javascript  = ON;
+	#----------------------------------
+?>
