@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -13,6 +13,8 @@
 	db_connect( $g_hostname, $g_db_username, $g_db_password, $g_database_name );
 	#check_access( DEVELOPER );
 
+	# we handle the case where the file is attached to a bug
+	# or attached to a project as a project doc.
 	switch ( $f_type ) {
 		case "bug":	$query = "SELECT *
 							FROM $g_mantis_bug_file_table
@@ -23,7 +25,6 @@
 							WHERE id='$f_id'";
 					break;
 	}
-
 	$result = db_query( $query );
 	$row = db_fetch_array( $result );
 	extract( $row, EXTR_PREFIX_ALL, "v" );
@@ -33,5 +34,10 @@
 	header( "Content-Disposition: filename=$v_filename" );
 	header( "Content-Description: Download Data" );
 
-	echo $v_content;
+	# dump file content to the connection.
+	if ( DISK == $g_file_upload_method ) {
+		readfile( $v_diskfile );
+	} else {
+		echo $v_content;
+	}
 ?>
\ No newline at end of file
