@@ -2,8 +2,8 @@
 /**
  * anon_login.php
  *
- * Mantis - a php based bugtracking system
- * Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+ # Mantis - a php based bugtracking system
+ # Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
  * This file copyright (C) 2002 August Zajonc - augustz@users.sourceforge.net
  * This program is distributed under the terms and conditions of the GPL
  * See the README and LICENSE files for details
@@ -23,5 +23,5 @@
  */
 	include("core_API.php");
 
-	header("Location: $g_login?f_username=$g_anonymous_account&f_perm_login=false");
+	print_header_redirect( "$g_login?f_username=$g_anonymous_account&f_perm_login=false" );
 ?>
\ No newline at end of file
