@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -68,6 +68,8 @@
 
 		## grab the username and email of the poster
     	$row2 = get_user_info_by_id_arr( $v_poster_id );
+		$t_poster_name	= "";
+		$t_poster_email	= "";
 		if ( $row2 ) {
 			$t_poster_name	= $row2["username"];
 			$t_poster_email	= $row2["email"];
