@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -19,9 +19,9 @@
 		# Add item
 		$query = "INSERT
 				INTO $g_mantis_project_table
-				( id, name, status, enabled, view_state, file_path, access_min, description )
+				( id, name, status, enabled, view_state, file_path, description )
 				VALUES
-				( null, '$f_name', '$f_status', '1', '$f_view_state', '$f_file_path', '$f_access_min', '$f_description' )";
+				( null, '$f_name', '$f_status', '1', '$f_view_state', '$f_file_path', '$f_description' )";
 	    $result = db_query( $query );
 	}
 
