@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -11,21 +11,14 @@
 	check_access( MANAGER );
 
 	if ( empty( $f_category ) ) {
-		echo $MANTIS_ERROR[ERROR_EMPTY_FIELD];
-		exit;
+		print_mantis_error( ERROR_EMPTY_FIELD );
 	}
 
 	$result = 0;
-	$duplicate = is_duplicate_category( $f_category, $f_project_id );
+	$duplicate = is_duplicate_category( $f_project_id, $f_category );
 	# check for empty case or duplicate
 	if ( !empty( $f_category )&& !$duplicate ) {
-		# insert category
-		$query = "INSERT
-				INTO $g_mantis_project_category_table
-				( project_id, category )
-				VALUES
-				( '$f_project_id', '$f_category' )";
-		$result = db_query( $query );
+		$result = category_add( $f_project_id, $f_category );
 	}
 
 	$t_redirect_url = $g_manage_project_edit_page."?f_project_id=".$f_project_id;
