@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -31,21 +31,14 @@
 				enabled='$f_enabled',
 				view_state='$f_view_state',
 				file_path='$f_file_path',
-				access_min='$f_access_min',
 				description='$f_description'
     		WHERE id='$f_project_id'";
     $result = db_query( $query );
 
     $t_redirect_url = $g_manage_project_menu_page;
-?>
-<?php print_page_top1() ?>
-<?php
 	if ( $result ) {
-		print_meta_redirect( $t_redirect_url );
+		print_header_redirect( $t_redirect_url );
+	} else {
+		print_mantis_error( ERROR_GENERIC );
 	}
-?>
-<?php print_page_top2() ?>
-
-<?php print_proceed( $result, $query, $t_redirect_url ) ?>
-
-<?php print_page_bot1( __FILE__ ) ?>
\ No newline at end of file
+?>
\ No newline at end of file
