@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -25,7 +25,7 @@
 
 <p>
 <div align="center">
-<table class="width50" cellspacing="1">
+<table class="width75" cellspacing="1">
 <form method="post" action="<?php echo $g_manage_user_update ?>">
 <input type="hidden" name="f_id" value="<?php echo $u_id ?>">
 <tr>
@@ -34,10 +34,10 @@
 	</td>
 </tr>
 <tr class="row-1">
-	<td class="category">
+	<td class="category" width="30%">
 		<?php echo $s_username ?>:
 	</td>
-	<td colspan="2">
+	<td colspan="2" width="70%">
 		<input type="text" size="16" maxlength="32" name="f_username" value="<?php echo $u_username ?>">
 	</td>
 </tr>
@@ -55,13 +55,13 @@
 	</td>
 	<td colspan="2">
 		<select name="f_access_level">
-			<?php print_enum_string_option_list( $s_access_levels_enum_string, $u_access_level ) ?>
+			<?php print_enum_string_option_list( "access_levels", $u_access_level ) ?>
 		</select>
 	</td>
 </tr>
 <tr class="row-2">
 	<td class="category">
-		<?php echo $s_enabled ?>
+		<?php echo $s_enabled ?>:
 	</td>
 	<td colspan="2">
 		<input type="checkbox" name="f_enabled" <?php if ( ON == $u_enabled ) echo "CHECKED" ?>>
@@ -69,7 +69,7 @@
 </tr>
 <tr class="row-1">
 	<td class="category">
-		<?php echo $s_protected ?>
+		<?php echo $s_protected ?>:
 	</td>
 	<td colspan="2">
 		<input type="checkbox" name="f_protected" <?php if ( ON == $u_protected ) echo "CHECKED" ?>>
@@ -110,4 +110,54 @@
 ?>
 </div>
 
+<?php ### BEGIN User to Project Add Form ?>
+<p>
+<div align="center">
+<table class="width75" cellspacing="1">
+<form method="post" action="<?php echo $g_manage_user_proj_add ?>">
+<input type="hidden" name="f_user_id" value="<?php echo $u_id ?>">
+<tr>
+	<td class="form-title" colspan="2">
+		<?php echo $s_add_user_title ?>
+	</td>
+</tr>
+<tr class="row-1" valign="top">
+	<td class="category" width="30%">
+		<?php echo $s_assigned_projects ?>:
+	</td>
+	<td width="70%">
+		<?php print_project_user_list( $u_id ) ?>
+	</td>
+</tr>
+<tr class="row-2" valign="top">
+	<td class="category">
+		<?php echo $s_unassigned_projects ?>:
+	</td>
+	<td>
+		<select name="f_project_id[]" multiple size="5">
+			<?php print_project_user_list_option_list2( $u_id ) ?>
+		</select>
+	</td>
+</tr>
+<tr class="row-1" valign="top">
+	<td class="category">
+		<?php echo $s_access_level ?>:
+	</td>
+	<td>
+		<select name="f_access_level">
+			<?php # No administrator choice ?>
+			<?php print_project_user_option_list( REPORTER ) ?>
+		</select>
+	</td>
+</tr>
+<tr>
+	<td class="center" colspan="2">
+		<input type="submit" value="<?php echo $s_add_user_button ?>">
+	</td>
+</tr>
+</form>
+</table>
+</div>
+<?php ### END User to Project Add Form ?>
+
 <?php print_page_bot1( __FILE__ ) ?>
