@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -12,19 +12,18 @@
 
 	$result = 0;
 	$good_upload = 0;
-	if ( is_uploaded_file( $f_file ) ) {
+	$disallowed = 0;
+	extract( $HTTP_POST_FILES['f_file'], EXTR_PREFIX_ALL, "f" );
+
+	if ( !file_type_check( $f_file_name ) ) {
+		$disallowed = 1;
+	} else if ( is_uploaded_file( $f_file ) ) {
 		$good_upload = 1;
-		$query = "SELECT file_path
-				FROM $g_mantis_project_table
-				WHERE id='$g_project_cookie_val'";
-		$result = db_query( $query );
-		$t_file_path = db_result( $result );
 
-		if ( !file_exists( $t_file_path ) ) {
-			echo $MANTIS_ERROR[ERROR_NO_DIRECTORY];
-			exit;
-		}
+		# grab the file path
+		$t_file_path = get_current_project_field( "file_path" );
 
+		# prepare variables for insertion
 		$f_title 		= string_prepare_text( $f_title );
 		$f_description 	= string_prepare_textarea( $f_description );
 
@@ -40,12 +39,11 @@
 									VALUES
 									(null, $g_project_cookie_val, '$f_title', '$f_description', '$t_file_path$f_file_name', '$f_file_name', '$t_file_path', $t_file_size, '$f_file_type', NOW(), '')";
 						} else {
-							echo $MANTIS_ERROR[ERROR_DUPLICATE_FILE];
-							exit;
+							print_mantis_error( ERROR_DUPLICATE_FILE );
 						}
 						break;
 			case DATABASE:
-						$t_content = addslashes( fread ( fopen( $f_file, "r" ), $t_file_size ) );
+						$t_content = addslashes( fread ( fopen( $f_file, "rb" ), $t_file_size ) );
 						$query = "INSERT INTO mantis_project_file_table
 								(id, project_id, title, description, diskfile, filename, folder, filesize, file_type, date_added, content)
 								VALUES
@@ -71,9 +69,11 @@
 	if ( $result ) {				# SUCCESS
 		PRINT "$s_operation_successful<p>";
 	} else {						# FAILURE
-		if ( 0 == $good_upload ) {
+		if ( 1 == $disallowed ) {
+			PRINT $MANTIS_ERROR[ERROR_FILE_DISALLOWED]."<p>";
+		} else if ( 0 == $good_upload ) {
 			PRINT $MANTIS_ERROR[ERROR_NO_FILE_SPECIFIED]."<p>";
-		} else {
+		} else if ( !$result ) {
 			print_sql_error( $query );
 		}
 	}
