@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -29,7 +29,7 @@
 	}
 
 	# Add item
-	setcookie( $g_project_cookie, $f_project_id, time()+$g_cookie_time_length );
+	setcookie( $g_project_cookie, $f_project_id, time()+$g_cookie_time_length, $g_cookie_path );
 
 	# redirect to 'same page' when switching projects.
 	# view_all_* pages, and summary
@@ -37,25 +37,24 @@
 	if ( 1 == $valid_project ) {
 		if ( !isset( $HTTP_REFERER ) || empty( $HTTP_REFERER ) ) {
 			$t_redirect_url = $g_main_page;
-		} else if ( eregi( $g_view_all_bug_page,$HTTP_REFERER ) ){
-			$t_redirect_url = $g_view_all_bug_page;
-		} else if ( eregi( $g_summary_page,$HTTP_REFERER ) ){
+		} else if ( eregi( $g_view_all_bug_page, $HTTP_REFERER ) ){
+			$t_redirect_url = $g_view_all_set."?f_type=0";
+		} else if ( eregi( $g_summary_page, $HTTP_REFERER ) ){
 			$t_redirect_url = $g_summary_page;
-		} else if ( eregi( $g_manage_project_user_menu_page,$HTTP_REFERER ) ){
-			$t_redirect_url = $g_manage_project_user_menu_page;
+		} else if ( eregi( $g_proj_user_menu_page, $HTTP_REFERER ) ){
+			$t_redirect_url = $g_proj_user_menu_page;
 		} else {
 			$t_redirect_url = $g_main_page;
 		}
 	}
 
-	if ( empty( $f_ref ) ) {
+	if ( !empty( $f_ref ) ) {
 		$t_redirect_url = $f_ref;
 	}
 
 	# clear view filter between projects
-	setcookie( $g_view_all_cookie );
-
-	if ( ( ON == $g_quick_proceed )&&( $result ) ) {
+	setcookie( $g_view_all_cookie,	"", -1, $g_cookie_path );
+	if ( $result ) {
 		print_header_redirect( $t_redirect_url );
 	}
 ?>
