@@ -1,6 +1,6 @@
 <?php
 	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000, 2001  Kenzaburo Ito - kenito@300baud.org
+	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 ?>
@@ -15,24 +15,24 @@
 	} else {
 		$specific_where = " project_id='$g_project_cookie_val'";
 	}
-	$t_res_val = RESOLVED;
+	$t_clo_val = CLOSED;
 	$query = "SELECT id, UNIX_TIMESTAMP(date_submitted) as date_submitted,
 			UNIX_TIMESTAMP(last_updated) as last_updated
 			FROM $g_mantis_bug_table
-			WHERE $specific_where AND status='$t_res_val'";
+			WHERE $specific_where AND status='$t_clo_val'";
 	$result = db_query( $query );
 	$bug_count = db_num_rows( $result );
 
-	$t_bug_id = 0;
+	$t_bug_id       = 0;
 	$t_largest_diff = 0;
-	$t_total_time = 0;
+	$t_total_time   = 0;
 	for ($i=0;$i<$bug_count;$i++) {
 		$row = db_fetch_array( $result );
-		$t_date_submitted = ($row["date_submitted"]);
-		$t_last_updated = $row["last_updated"];
+		$t_date_submitted = $row["date_submitted"];
+		$t_last_updated   = $row["last_updated"];
 
 		if ($t_last_updated < $t_date_submitted) {
-			$t_last_updated = 0;
+			$t_last_updated   = 0;
 			$t_date_submitted = 0;
 		}
 
@@ -73,7 +73,7 @@
 				<?php echo $s_by_status ?>:
 			</td>
 		</tr>
-		<?php print_bug_enum_summary( $s_status_enum_string, "status" ) ?>
+		<?php print_bug_enum_summary( $g_status_enum_string, "status" ) ?>
 		</table>
 	</td>
 	<td width="50%">
@@ -97,7 +97,7 @@
 				<?php echo $s_by_severity ?>:
 			</td>
 		</tr>
-		<?php print_bug_enum_summary( $s_severity_enum_string, "severity" ) ?>
+		<?php print_bug_enum_summary( $g_severity_enum_string, "severity" ) ?>
 		</table>
 	</td>
 	<td>
@@ -108,7 +108,7 @@
 				<?php echo $s_by_resolution ?>:
 			</td>
 		</tr>
-		<?php print_bug_enum_summary( $s_resolution_enum_string, "resolution" ) ?>
+		<?php print_bug_enum_summary( $g_resolution_enum_string, "resolution" ) ?>
 		</table>
 	</td>
 </tr>
@@ -132,7 +132,7 @@
 				<?php echo $s_by_priority ?>:
 			</td>
 		</tr>
-		<?php print_bug_enum_summary( $s_priority_enum_string, "priority" ) ?>
+		<?php print_bug_enum_summary( $g_priority_enum_string, "priority" ) ?>
 		</table>
 	</td>
 </tr>
@@ -150,13 +150,11 @@
 				<?php echo $s_longest_open_bug ?>
 			</td>
 			<td width="50%">
-				<?php if ($t_bug_id>0) { ?>
-					<?php if ( ON == get_current_user_pref_field( "advanced_view" ) ) { ?>
-						<a href="<?php echo $g_view_bug_advanced_page ?>?f_id=<?php echo $t_bug_id ?>"><?php echo $t_bug_id ?></a>
-					<?php } else {?>
-						<a href="<?php echo $g_view_bug_page ?>?f_id=<?php echo $t_bug_id ?>"><?php echo $t_bug_id ?></a>
-					<?php } ?>
-				<?php } ?>
+				<?php
+					if ($t_bug_id>0) {
+						print_bug_link( $t_bug_id );
+					}
+				?>
 			</td>
 		</tr>
 		<tr class="row-2">
